@@ -3,7 +3,7 @@
  * \brief abstraction for all consumer services
  * \see mlt_consumer_s
  *
- * Copyright (C) 2003-2023 Meltytech, LLC
+ * Copyright (C) 2003-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,7 +31,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
+#ifdef _MSC_VER
+#include <gettimeofday.h>
+#else
 #include <sys/time.h>
+#endif
 
 /** Define this if you want an automatic deinterlace (if necessary) when the
  * consumer's producer is not running at normal speed.
@@ -309,6 +314,9 @@ static void mlt_consumer_property_changed(mlt_properties owner,
         mlt_profile profile = mlt_service_profile(MLT_CONSUMER_SERVICE(self));
         if (profile)
             profile->colorspace = mlt_properties_get_int(properties, "colorspace");
+    } else if (!strcmp(name, "mlt_color_trc")) {
+        mlt_properties properties = MLT_CONSUMER_PROPERTIES(self);
+        mlt_properties_clear(properties, "_ct_filter");
     }
 }
 
@@ -470,6 +478,11 @@ int mlt_consumer_start(mlt_consumer self)
         return error;
 
     consumer_private *priv = self->local;
+    mlt_profile profile = mlt_service_profile(MLT_CONSUMER_SERVICE(self));
+
+    if (!mlt_profile_is_valid(profile)) {
+        return 1;
+    }
 
     // Stop listening to the property-changed event
     mlt_event_block(priv->event_listener);
@@ -490,7 +503,6 @@ int mlt_consumer_start(mlt_consumer self)
     if (test_card != NULL) {
         if (mlt_properties_get_data(properties, "test_card_producer", NULL) == NULL) {
             // Create a test card producer
-            mlt_profile profile = mlt_service_profile(MLT_CONSUMER_SERVICE(self));
             mlt_producer producer = mlt_factory_producer(profile, NULL, test_card);
 
             // Do we have a producer
@@ -515,7 +527,7 @@ int mlt_consumer_start(mlt_consumer self)
     }
 
     // The profile could have changed between a stop and a restart.
-    apply_profile_properties(self, mlt_service_profile(MLT_CONSUMER_SERVICE(self)), properties);
+    apply_profile_properties(self, profile, properties);
 
     // Set the frame duration in microseconds for the frame-dropping heuristic
     int frame_rate_num = mlt_properties_get_int(properties, "frame_rate_num");
@@ -682,12 +694,43 @@ mlt_frame mlt_consumer_get_frame(mlt_consumer self)
         mlt_properties_set(frame_properties,
                            "consumer.color_trc",
                            mlt_properties_get(properties, "color_trc"));
+        mlt_properties_set(frame_properties,
+                           "consumer.mlt_color_trc",
+                           mlt_properties_get(properties, "mlt_color_trc"));
         mlt_properties_set(frame_properties,
                            "consumer.channel_layout",
                            mlt_properties_get(properties, "channel_layout"));
         mlt_properties_set(frame_properties,
                            "consumer.color_range",
                            mlt_properties_get(properties, "color_range"));
+
+        if (mlt_properties_get(properties, "mlt_color_trc")) {
+            // Add a normalize filter to convert the mlt_color_trc to color_trc
+            mlt_filter ct_filter = (mlt_filter) mlt_properties_get_data(properties,
+                                                                        "_ct_filter",
+                                                                        NULL);
+            if (!ct_filter) {
+                mlt_profile profile = mlt_service_profile(service);
+                ct_filter = mlt_factory_filter(profile, "color_transform", NULL);
+                if (ct_filter) {
+                    mlt_properties cs_properties = MLT_FILTER_PROPERTIES(ct_filter);
+                    const char *color_trc_str = mlt_properties_get(properties, "color_trc");
+                    mlt_color_trc trc = mlt_image_color_trc_id(color_trc_str);
+                    if (trc == mlt_color_trc_none)
+                        trc = mlt_image_default_trc(profile->colorspace);
+                    mlt_properties_set_int(cs_properties, "force_trc", trc);
+                    mlt_properties_set_data(properties,
+                                            "_ct_filter",
+                                            ct_filter,
+                                            0,
+                                            (mlt_destructor) mlt_filter_close,
+                                            NULL);
+                }
+            }
+            if (ct_filter) {
+                mlt_filter_process(ct_filter, frame);
+            }
+        }
     }
 
     // Return the frame
