@@ -2,7 +2,7 @@
  * \file mlt_factory.c
  * \brief the factory method interfaces
  *
- * Copyright (C) 2003-2022 Meltytech, LLC
+ * Copyright (C) 2003-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -153,7 +153,10 @@ mlt_repository mlt_factory_init(const char *directory)
 #ifdef __APPLE__
         _NSGetExecutablePath(path, &size);
 #else
-        readlink("/proc/self/exe", path, size);
+        ssize_t len = readlink("/proc/self/exe", path, size - 1);
+        if (len != -1) {
+            path[len] = '\0';
+        }
 #endif
         char *appdir = mlt_dirname(mlt_dirname(strdup(path)));
         mlt_properties_set(global_properties, "MLT_APPDIR", appdir);
@@ -208,9 +211,6 @@ mlt_repository mlt_factory_init(const char *directory)
 
         // Create the repository of services
         repository = mlt_repository_init(mlt_directory);
-
-        // Force a clean up when app closes
-        atexit(mlt_factory_close);
     }
 
     if (global_properties) {
@@ -307,7 +307,7 @@ static void set_common_properties(mlt_properties properties,
     mlt_properties_set(properties, "mlt_type", type);
     if (mlt_properties_get_int(properties, "_mlt_service_hidden") == 0)
         mlt_properties_set(properties, "mlt_service", service);
-    if (profile != NULL)
+    if (profile != NULL && mlt_properties_get_data(properties, "_profile", NULL) == NULL)
         mlt_properties_set_data(properties, "_profile", profile, 0, NULL, NULL);
 }
 
@@ -327,6 +327,9 @@ mlt_producer mlt_factory_producer(mlt_profile profile, const char *service, cons
 {
     mlt_producer obj = NULL;
 
+    if (profile && !mlt_profile_is_valid(profile))
+        return obj;
+
     // Pick up the default normalizing producer if necessary
     if (service == NULL)
         service = mlt_environment("MLT_PRODUCER");
