@@ -3,7 +3,7 @@
  * \brief Image class
  * \see mlt_mlt_image_s
  *
- * Copyright (C) 2020-2024 Meltytech, LLC
+ * Copyright (C) 2020-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -195,6 +195,8 @@ int mlt_image_calculate_size(mlt_image self)
         return self->width * self->height * 3;
     case mlt_image_yuv444p10:
         return self->width * self->height * 6;
+    case mlt_image_rgba64:
+        return self->width * self->height * 4 * 2;
     case mlt_image_none:
     case mlt_image_invalid:
         return 0;
@@ -232,6 +234,8 @@ const char *mlt_image_format_name(mlt_image_format format)
         return "yuv420p10";
     case mlt_image_yuv444p10:
         return "yuv444p10";
+    case mlt_image_rgba64:
+        return "rgba64";
     case mlt_image_invalid:
         return "invalid";
     }
@@ -258,6 +262,333 @@ mlt_image_format mlt_image_format_id(const char *name)
     return mlt_image_invalid;
 }
 
+/** Get the short name for a color transfer characteristics.
+ *
+ * \public \memberof mlt_image_s
+ * \param trc the color transfer characteristics
+ * \return a string
+ */
+
+const char *mlt_image_color_trc_name(mlt_color_trc trc)
+{
+    switch (trc) {
+    case mlt_color_trc_none:
+    case mlt_color_trc_unspecified:
+    case mlt_color_trc_reserved:
+        return "none";
+    case mlt_color_trc_bt709:
+        return "bt709";
+    case mlt_color_trc_gamma22:
+        return "bt470m";
+    case mlt_color_trc_gamma28:
+        return "bt470bg";
+    case mlt_color_trc_smpte170m:
+        return "smpte170m";
+    case mlt_color_trc_smpte240m:
+        return "smpte240m";
+    case mlt_color_trc_linear:
+        return "linear";
+    case mlt_color_trc_log:
+        return "log100";
+    case mlt_color_trc_log_sqrt:
+        return "log316";
+    case mlt_color_trc_iec61966_2_4:
+        return "iec61966-2-4";
+    case mlt_color_trc_bt1361_ecg:
+        return "bt1361e";
+    case mlt_color_trc_iec61966_2_1:
+        return "iec61966-2-1";
+    case mlt_color_trc_bt2020_10:
+        return "bt2020-10";
+    case mlt_color_trc_bt2020_12:
+        return "bt2020-12";
+    case mlt_color_trc_smpte2084:
+        return "smpte2084";
+    case mlt_color_trc_smpte428:
+        return "smpte428";
+    case mlt_color_trc_arib_std_b67:
+        return "arib-std-b67";
+    case mlt_color_trc_invalid:
+        return "invalid";
+    }
+    return "none";
+}
+
+/** Get the id of color transfer characteristics from short name.
+ *
+ * \public \memberof mlt_image_s
+ * \param name the color trc short name
+ * \return a color trc
+ */
+
+mlt_color_trc mlt_image_color_trc_id(const char *name)
+{
+    if (!name) {
+        return mlt_color_trc_none;
+    }
+
+    mlt_color_trc c;
+    for (c = mlt_color_trc_none; c <= mlt_color_trc_invalid; c++) {
+        const char *s = mlt_image_color_trc_name(c);
+        if (!strcmp(s, name))
+            return c;
+    }
+
+    // Fall back to see if it was specified as a number
+    int value = strtol(name, NULL, 10);
+    if (value && value < mlt_color_trc_invalid)
+        return value;
+
+    return mlt_color_trc_none;
+}
+
+const char *mlt_image_colorspace_name(mlt_colorspace colorspace)
+{
+    switch (colorspace) {
+    case mlt_colorspace_rgb:
+        return "rgb";
+    case mlt_colorspace_bt709:
+        return "bt709";
+    case mlt_colorspace_unspecified:
+        return "unspecified";
+    case mlt_colorspace_reserved:
+        return "reserved";
+    case mlt_colorspace_fcc:
+        return "fcc";
+    case mlt_colorspace_bt470bg:
+        return "bt470bg";
+    case mlt_colorspace_smpte170m:
+        return "smpte170m";
+    case mlt_colorspace_smpte240m:
+        return "smpte240m";
+    case mlt_colorspace_ycgco:
+        return "ycgco";
+    case mlt_colorspace_bt2020_ncl:
+        return "bt2020nc";
+    case mlt_colorspace_bt2020_cl:
+        return "bt2020c";
+    case mlt_colorspace_smpte2085:
+        return "smpte2085";
+    case mlt_colorspace_bt601:
+        return "bt601";
+    case mlt_colorspace_invalid:
+        return "invalid";
+    }
+    return "invalid";
+}
+
+mlt_colorspace mlt_image_colorspace_id(const char *name)
+{
+    if (!name) {
+        return mlt_colorspace_invalid;
+    }
+    const mlt_colorspace colorspaces[] = {mlt_colorspace_rgb,
+                                          mlt_colorspace_bt709,
+                                          mlt_colorspace_unspecified,
+                                          mlt_colorspace_reserved,
+                                          mlt_colorspace_fcc,
+                                          mlt_colorspace_bt470bg,
+                                          mlt_colorspace_smpte170m,
+                                          mlt_colorspace_smpte240m,
+                                          mlt_colorspace_ycgco,
+                                          mlt_colorspace_bt2020_ncl,
+                                          mlt_colorspace_bt2020_cl,
+                                          mlt_colorspace_smpte2085,
+                                          mlt_colorspace_bt601,
+                                          mlt_colorspace_invalid};
+
+    // Fall back to see if it was specified as a number
+    int value = strtol(name, NULL, 10);
+    if (!value && strcmp(name, "0"))
+        value = -1; // strtol returned an error;
+
+    for (int i = 0; i < sizeof(colorspaces) / sizeof(colorspaces[0]); i++) {
+        const char *s = mlt_image_colorspace_name(colorspaces[i]);
+        if (value == colorspaces[i] || !strcmp(s, name))
+            return colorspaces[i];
+    }
+
+    return mlt_colorspace_invalid;
+}
+
+const char *mlt_image_color_pri_name(mlt_color_primaries primaries)
+{
+    switch (primaries) {
+    case mlt_color_pri_none:
+        return "none";
+    case mlt_color_pri_bt709:
+        return "bt709";
+    case mlt_color_pri_bt470m:
+        return "bt470m";
+    case mlt_color_pri_bt470bg:
+        return "bt470bg";
+    case mlt_color_pri_smpte170m:
+        return "smpte170m";
+    case mlt_color_pri_film:
+        return "film";
+    case mlt_color_pri_bt2020:
+        return "bt2020";
+    case mlt_color_pri_smpte428:
+        return "smpte428";
+    case mlt_color_pri_smpte431:
+        return "smpte431";
+    case mlt_color_pri_smpte432:
+        return "smpte432";
+    case mlt_color_pri_invalid:
+        return "invalid";
+    }
+    return "invalid";
+}
+
+mlt_color_primaries mlt_image_color_pri_id(const char *name)
+{
+    if (!name) {
+        return mlt_color_pri_none;
+    }
+
+    const mlt_color_primaries primaries[] = {mlt_color_pri_none,
+                                             mlt_color_pri_bt709,
+                                             mlt_color_pri_bt470m,
+                                             mlt_color_pri_bt470bg,
+                                             mlt_color_pri_smpte170m,
+                                             mlt_color_pri_film,
+                                             mlt_color_pri_bt2020,
+                                             mlt_color_pri_smpte428,
+                                             mlt_color_pri_smpte431,
+                                             mlt_color_pri_smpte432,
+                                             mlt_color_pri_invalid};
+
+    // Fall back to see if it was specified as a number
+    int value = strtol(name, NULL, 10);
+    if (!value && strcmp(name, "0"))
+        value = -1; // strtol returned an error;
+
+    for (int i = 0; name && i < sizeof(primaries) / sizeof(primaries[0]); i++) {
+        const char *s = mlt_image_color_pri_name(primaries[i]);
+        if (value == primaries[i] || !strcmp(s, name))
+            return primaries[i];
+    }
+
+    return mlt_color_pri_none;
+}
+
+/** Get the default colorspace for a given image format.
+ *
+ * \public \memberof mlt_image_s
+ * \param format the format
+ * \param height the image height. Pass 0 if you do not know.
+ * \return a colorspace
+ */
+
+mlt_colorspace mlt_image_default_colorspace(mlt_image_format format, int height)
+{
+    mlt_colorspace colorspace = mlt_colorspace_bt709;
+    switch (format) {
+    case mlt_image_rgb:
+    case mlt_image_rgba:
+    case mlt_image_rgba64:
+    case mlt_image_movit:
+    case mlt_image_opengl_texture:
+        colorspace = mlt_colorspace_rgb;
+        break;
+    case mlt_image_yuv422:
+    case mlt_image_yuv420p:
+    case mlt_image_yuv422p16:
+    case mlt_image_yuv420p10:
+    case mlt_image_yuv444p10:
+        if (height < 576) {
+            // Assume NTSC
+            colorspace = mlt_colorspace_smpte170m;
+        } else if (height < 720) {
+            // Assume PAL
+            colorspace = mlt_colorspace_bt470bg;
+        } else {
+            // Assume HDTV
+            colorspace = mlt_colorspace_bt709;
+        }
+        break;
+    case mlt_image_none:
+    case mlt_image_invalid:
+        break;
+    }
+    return colorspace;
+}
+
+/** Get the default color transfer characteristics for a given colorspace.
+ *
+ * \public \memberof mlt_image_s
+ * \param colorspace the colorspace
+ * \return a color trc
+ */
+
+mlt_color_trc mlt_image_default_trc(mlt_colorspace colorspace)
+{
+    switch (colorspace) {
+    case mlt_colorspace_rgb:
+        return mlt_color_trc_iec61966_2_1;
+    case mlt_colorspace_bt709:
+        return mlt_color_trc_bt709;
+    case mlt_colorspace_bt470bg:
+        return mlt_color_trc_gamma28;
+    case mlt_colorspace_smpte170m:
+        return mlt_color_trc_smpte170m;
+    case mlt_colorspace_smpte240m:
+        return mlt_color_trc_smpte240m;
+    case mlt_colorspace_bt2020_ncl:
+        return mlt_color_trc_bt2020_10;
+    case mlt_colorspace_bt2020_cl:
+        return mlt_color_trc_bt2020_10;
+    case mlt_colorspace_bt601:
+        return mlt_color_trc_smpte170m;
+    case mlt_colorspace_smpte2085:
+    case mlt_colorspace_fcc:
+    case mlt_colorspace_ycgco:
+    case mlt_colorspace_unspecified:
+    case mlt_colorspace_reserved:
+    case mlt_colorspace_invalid:
+        break;
+    }
+    return mlt_color_trc_bt709;
+}
+
+/** Get the default color primaries for a given colorspace.
+ *
+ * \public \memberof mlt_image_s
+ * \param colorspace the colorspace
+ * \param height the image height. Pass 0 if you do not know.
+ * \return a color primaries
+ */
+
+mlt_color_primaries mlt_image_default_primaries(mlt_colorspace colorspace, int height)
+{
+    switch (colorspace) {
+    case mlt_colorspace_rgb:
+    case mlt_colorspace_bt709:
+        return mlt_color_pri_bt709;
+    case mlt_colorspace_bt470bg:
+        return mlt_color_pri_bt470bg;
+    case mlt_colorspace_smpte170m:
+        return mlt_color_pri_smpte170m;
+    case mlt_colorspace_smpte240m:
+        return mlt_color_pri_smpte170m;
+    case mlt_colorspace_bt2020_ncl:
+        return mlt_color_pri_bt2020;
+    case mlt_colorspace_bt2020_cl:
+        return mlt_color_pri_bt2020;
+    case mlt_colorspace_bt601:
+        return height >= 576 ? mlt_color_pri_bt470bg : mlt_color_pri_smpte170m;
+    case mlt_colorspace_fcc:
+        return mlt_color_pri_bt470m;
+    case mlt_colorspace_smpte2085:
+    case mlt_colorspace_ycgco:
+    case mlt_colorspace_unspecified:
+    case mlt_colorspace_reserved:
+    case mlt_colorspace_invalid:
+        break;
+    }
+    return mlt_color_pri_bt709;
+}
+
 /** Fill an image with black.
   *
   * \bug This does not respect full range YUV if needed.
@@ -276,7 +607,8 @@ void mlt_image_fill_black(mlt_image self)
     case mlt_image_opengl_texture:
         return;
     case mlt_image_rgb:
-    case mlt_image_rgba: {
+    case mlt_image_rgba:
+    case mlt_image_rgba64: {
         int size = mlt_image_calculate_size(self);
         memset(self->planes[0], 0, size);
         break;
@@ -432,6 +764,20 @@ void mlt_image_fill_checkerboard(mlt_image self, double sample_aspect_ratio)
         memset(self->planes[1], 128, self->height * self->strides[1] / 2);
         memset(self->planes[2], 128, self->height * self->strides[2] / 2);
     } break;
+    case mlt_image_rgba64: {
+        uint16_t *p = (uint16_t *) self->planes[0];
+        for (int i = 0; i < self->height; i++) {
+            for (int j = 0; j < self->width; j++) {
+                uint16_t color = ((((i + oy) / h) % 2) ^ (((j + ox) / w) % 2)) ? gray1 : gray2;
+                color *= 256;
+                p[0] = color;
+                p[1] = color;
+                p[2] = color;
+                p[3] = 0xffff;
+                p += 4;
+            }
+        }
+    } break;
     }
 }
 
@@ -454,7 +800,8 @@ void mlt_image_fill_white(mlt_image self, int full_range)
     case mlt_image_opengl_texture:
         return;
     case mlt_image_rgb:
-    case mlt_image_rgba: {
+    case mlt_image_rgba:
+    case mlt_image_rgba64: {
         int size = mlt_image_calculate_size(self);
         memset(self->planes[0], 255, size);
         break;
@@ -526,11 +873,55 @@ void mlt_image_fill_opaque(mlt_image self)
                 *pLine += 4;
             }
         }
+    } else if (self->format == mlt_image_rgba64 && self->planes[0] != NULL) {
+        for (int line = 0; line < self->height; line++) {
+            uint16_t *pLine = (uint16_t *) self->planes[0] + (self->strides[0] * line) + 3;
+            for (int pixel = 0; pixel < self->width; pixel++) {
+                *pLine = 0xffff;
+                *pLine += 4;
+            }
+        }
     } else if (self->planes[3] != NULL) {
         memset(self->planes[3], 255, self->height * self->strides[3]);
     }
 }
 
+/** Check if the alpha channel of an image is opaque
+ *
+ * \public \memberof mlt_image_s
+ * \param self a mlt_image
+ * \return true (1) or false (0) if the image is opaque
+ */
+extern int mlt_image_is_opaque(mlt_image self)
+{
+    if (!self->data)
+        return 0;
+
+    int pixels = self->width * self->height;
+
+    if (self->format == mlt_image_rgba && self->planes[0] != NULL) {
+        int samples = pixels * 4;
+        uint8_t *img = self->planes[0];
+        for (int i = 0; i < samples; i += 4) {
+            if (img[i + 3] != 0xff)
+                return 0;
+        }
+    } else if (self->format == mlt_image_rgba64 && self->planes[0] != NULL) {
+        int samples = pixels * 4;
+        uint16_t *img = (uint16_t *) self->planes[0];
+        for (int i = 0; i < samples; i += 4) {
+            if (img[i + 3] != 0xffff)
+                return 0;
+        }
+    } else if (self->planes[3] != NULL) {
+        for (int i = 0; i < pixels; i++) {
+            if (self->planes[3][i] != 0xff)
+                return 0;
+        }
+    }
+    return 1;
+}
+
 /** Get the number of bytes needed for an image.
   *
   * \public \memberof mlt_image_s
@@ -576,6 +967,10 @@ int mlt_image_format_size(mlt_image_format format, int width, int height, int *b
         if (bpp)
             *bpp = 6;
         return 6 * height * width;
+    case mlt_image_rgba64:
+        if (bpp)
+            *bpp = 8;
+        return 8 * height * width;
     default:
         if (bpp)
             *bpp = 0;
