@@ -23,6 +23,7 @@
 #ifndef MLT_PROFILE_H
 #define MLT_PROFILE_H
 
+#include "mlt_export.h"
 #include "mlt_types.h"
 
 /** \brief Profile class
@@ -43,22 +44,23 @@ struct mlt_profile_s
     int sample_aspect_den;  /**< the denominator of the pixel aspect ratio */
     int display_aspect_num; /**< the numerator of the image aspect ratio in case it can not be simply derived (e.g. ITU-R 601) */
     int display_aspect_den; /**< the denominator of the image aspect ratio in case it can not be simply derived (e.g. ITU-R 601) */
-    int colorspace; /**< the Y'CbCr colorspace standard: `601` for ITU-R 601, `709` for ITU-R 709, `240` for SMPTE240M, `2020` for ITU-R BT.2020 non-constant luminance, `2021` for ITU-R BT.2020 constant luminance */
+    int colorspace;         /**< the Y'CbCr colorspace standard: see mlt_colorspace */
     int is_explicit; /**< used internally to indicate if the profile was requested explicitly or computed or defaulted */
 };
 
-extern mlt_profile mlt_profile_init(const char *name);
-extern mlt_profile mlt_profile_load_file(const char *file);
-extern mlt_profile mlt_profile_load_properties(mlt_properties properties);
-extern mlt_profile mlt_profile_load_string(const char *string);
-extern double mlt_profile_fps(mlt_profile profile);
-extern double mlt_profile_sar(mlt_profile profile);
-extern double mlt_profile_dar(mlt_profile profile);
-extern void mlt_profile_close(mlt_profile profile);
-extern mlt_profile mlt_profile_clone(mlt_profile profile);
-extern mlt_properties mlt_profile_list();
-extern void mlt_profile_from_producer(mlt_profile profile, mlt_producer producer);
-extern char *mlt_profile_lumas_dir(mlt_profile profile);
-extern double mlt_profile_scale_width(mlt_profile profile, int width);
-extern double mlt_profile_scale_height(mlt_profile profile, int height);
+MLT_EXPORT mlt_profile mlt_profile_init(const char *name);
+MLT_EXPORT mlt_profile mlt_profile_load_file(const char *file);
+MLT_EXPORT mlt_profile mlt_profile_load_properties(mlt_properties properties);
+MLT_EXPORT mlt_profile mlt_profile_load_string(const char *string);
+MLT_EXPORT double mlt_profile_fps(mlt_profile profile);
+MLT_EXPORT double mlt_profile_sar(mlt_profile profile);
+MLT_EXPORT double mlt_profile_dar(mlt_profile profile);
+MLT_EXPORT void mlt_profile_close(mlt_profile profile);
+MLT_EXPORT mlt_profile mlt_profile_clone(mlt_profile profile);
+MLT_EXPORT mlt_properties mlt_profile_list();
+MLT_EXPORT void mlt_profile_from_producer(mlt_profile profile, mlt_producer producer);
+MLT_EXPORT char *mlt_profile_lumas_dir(mlt_profile profile);
+MLT_EXPORT double mlt_profile_scale_width(mlt_profile profile, int width);
+MLT_EXPORT double mlt_profile_scale_height(mlt_profile profile, int height);
+MLT_EXPORT int mlt_profile_is_valid(mlt_profile profile);
 #endif
