@@ -2,7 +2,7 @@
  * \file mlt_types.h
  * \brief Provides forward definitions of all public types
  *
- * Copyright (C) 2003-2023 Meltytech, LLC
+ * Copyright (C) 2003-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,19 +22,15 @@
 #ifndef MLT_TYPES_H
 #define MLT_TYPES_H
 
-#ifndef GCC_VERSION
-#define GCC_VERSION (__GNUC__ * 10000 + __GNUC_MINOR__ * 100 + __GNUC_PATCHLEVEL__)
-#endif
-
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+#include "mlt_export.h"
 #include "mlt_pool.h"
 #include <inttypes.h>
 #include <limits.h>
 #include <stdio.h>
-
 #ifndef PATH_MAX
 #define PATH_MAX 4096
 #endif
@@ -52,6 +48,7 @@ typedef enum {
     mlt_image_yuv422p16, /**< planar YUV 4:2:2, 32bpp, (1 Cr & Cb sample per 2x1 Y samples), little-endian */
     mlt_image_yuv420p10, /**< planar YUV 4:2:0, 15bpp, (1 Cr & Cb sample per 2x2 Y samples), little-endian */
     mlt_image_yuv444p10, /**< planar YUV 4:4:4, 30bpp, (1 Cr & Cb sample per 1x1 Y samples), little-endian */
+    mlt_image_rgba64, /**< 16-bit RGB with alpha channel */
     mlt_image_invalid
 } mlt_image_format;
 
@@ -100,21 +97,62 @@ typedef enum {
 /** Colorspace definitions */
 
 typedef enum {
-    mlt_colorspace_rgb = 0,   ///< order of coefficients is actually GBR, also IEC 61966-2-1 (sRGB)
-    mlt_colorspace_bt709 = 1, ///< also ITU-R BT1361 / IEC 61966-2-4 xvYCC709 / SMPTE RP177 Annex B
+    mlt_colorspace_rgb = 0, ///< order of coefficients is actually GBR, also IEC 61966-2-1 (sRGB)
+    mlt_colorspace_bt709 = 709, ///< also ITU-R BT1361 / IEC 61966-2-4 xvYCC709 / SMPTE RP177 Annex B
     mlt_colorspace_unspecified = 2,
     mlt_colorspace_reserved = 3,
     mlt_colorspace_fcc = 4, ///< FCC Title 47 Code of Federal Regulations 73.682 (a)(20)
     mlt_colorspace_bt470bg
-    = 5, ///< also ITU-R BT601-6 625 / ITU-R BT1358 625 / ITU-R BT1700 625 PAL & SECAM / IEC 61966-2-4 xvYCC601
-    mlt_colorspace_smpte170m = 6, ///< also ITU-R BT601-6 525 / ITU-R BT1358 525 / ITU-R BT1700 NTSC
-    mlt_colorspace_smpte240m = 7, ///< functionally identical to above
-    mlt_colorspace_ycgco = 8,     ///< Used by Dirac / VC-2 and H.264 FRext, see ITU-T SG16
-    mlt_colorspace_bt2020_ncl = 9, ///< ITU-R BT2020 non-constant luminance system
-    mlt_colorspace_bt2020_cl = 10, ///< ITU-R BT2020 constant luminance system
-    mlt_colorspace_smpte2085 = 11, ///< SMPTE 2085, Y'D'zD'x
+    = 470, ///< also ITU-R BT601-6 625 / ITU-R BT1358 625 / ITU-R BT1700 625 PAL & SECAM / IEC 61966-2-4 xvYCC601
+    mlt_colorspace_smpte170m = 170, ///< also ITU-R BT601-6 525 / ITU-R BT1358 525 / ITU-R BT1700 NTSC
+    mlt_colorspace_smpte240m = 240,   ///< functionally identical to above
+    mlt_colorspace_ycgco = 8,         ///< Used by Dirac / VC-2 and H.264 FRext, see ITU-T SG16
+    mlt_colorspace_bt2020_ncl = 2020, ///< ITU-R BT2020 non-constant luminance system
+    mlt_colorspace_bt2020_cl = 2021,  ///< ITU-R BT2020 constant luminance system
+    mlt_colorspace_smpte2085 = 11,    ///< SMPTE 2085, Y'D'zD'x
+    mlt_colorspace_bt601 = 601,       ///< BT.470 (625/PAL) or SMPTE170M (525/NTSC)
+    mlt_colorspace_invalid
 } mlt_colorspace;
 
+typedef enum {
+    mlt_color_trc_none = 0,
+    mlt_color_trc_bt709 = 1, ///< also ITU-R BT1361
+    mlt_color_trc_unspecified = 2,
+    mlt_color_trc_reserved = 3,
+    mlt_color_trc_gamma22 = 4, ///< also ITU-R BT470M / ITU-R BT1700 625 PAL & SECAM
+    mlt_color_trc_gamma28 = 5, ///< also ITU-R BT470BG
+    mlt_color_trc_smpte170m
+    = 6, ///< also ITU-R BT601-6 525 or 625 / ITU-R BT1358 525 or 625 / ITU-R BT1700 NTSC
+    mlt_color_trc_smpte240m = 7,
+    mlt_color_trc_linear = 8,    ///< "Linear transfer characteristics"
+    mlt_color_trc_log = 9,       ///< "Logarithmic transfer characteristic (100:1 range)"
+    mlt_color_trc_log_sqrt = 10, ///< "Logarithmic transfer characteristic (100 * Sqrt(10) : 1 range)"
+    mlt_color_trc_iec61966_2_4 = 11, ///< IEC 61966-2-4
+    mlt_color_trc_bt1361_ecg = 12,   ///< ITU-R BT1361 Extended Colour Gamut
+    mlt_color_trc_iec61966_2_1 = 13, ///< IEC 61966-2-1 (sRGB or sYCC)
+    mlt_color_trc_bt2020_10 = 14,    ///< ITU-R BT2020 for 10-bit system
+    mlt_color_trc_bt2020_12 = 15,    ///< ITU-R BT2020 for 12-bit system
+    mlt_color_trc_smpte2084 = 16,    ///< SMPTE ST 2084 for 10-, 12-, 14- and 16-bit systems
+    mlt_color_trc_smpte428 = 17,     ///< SMPTE ST 428-1
+    mlt_color_trc_arib_std_b67 = 18, ///< ARIB STD-B67, known as "Hybrid log-gamma"
+    mlt_color_trc_invalid
+} mlt_color_trc;
+
+typedef enum {
+    mlt_color_pri_none = 0,
+    mlt_color_pri_bt709 = 1,  ///< also ITU-R BT1361 / IEC 61966-2-4 / SMPTE RP177 Annex B
+    mlt_color_pri_bt470m = 4, ///< also FCC Title 47 Code of Federal Regulations 73.682 (a)(20)
+    mlt_color_pri_bt470bg
+    = 5, ///< also ITU-R BT601-6 625 / ITU-R BT1358 625 / ITU-R BT1700 625 PAL & SECAM
+    mlt_color_pri_smpte170m = 6, ///< also ITU-R BT601-6 525 / ITU-R BT1358 525 / ITU-R BT1700 NTSC
+    mlt_color_pri_film = 8,      ///< colour filters using Illuminant C
+    mlt_color_pri_bt2020 = 9,    ///< ITU-R BT2020
+    mlt_color_pri_smpte428 = 10, ///< SMPTE ST 428-1 (CIE 1931 XYZ)
+    mlt_color_pri_smpte431 = 11, ///< SMPTE ST 431-2 (2011) / DCI P3
+    mlt_color_pri_smpte432 = 12, ///< SMPTE ST 432-1 (2010) / P3 D65 / Display P3
+    mlt_color_pri_invalid
+} mlt_color_primaries;
+
 typedef enum {
     mlt_deinterlacer_none,
     mlt_deinterlacer_onefield,
@@ -296,25 +334,30 @@ typedef void *(*mlt_thread_function_t)(void *);      /**< generic thread functio
 #include <pthread.h>
 /* Win32 compatibility function declarations */
 #if !defined(__MINGW32__)
-extern int usleep(unsigned int useconds);
+MLT_EXPORT int usleep(unsigned int useconds);
 #endif
 #ifndef WIN_PTHREADS_TIME_H
-extern int nanosleep(const struct timespec *rqtp, struct timespec *rmtp);
+MLT_EXPORT int nanosleep(const struct timespec *rqtp, struct timespec *rmtp);
 #endif
-extern int setenv(const char *name, const char *value, int overwrite);
-extern char *getlocale();
-extern FILE *win32_fopen(const char *filename_utf8, const char *mode_utf8);
+MLT_EXPORT int setenv(const char *name, const char *value, int overwrite);
+MLT_EXPORT char *getlocale();
+MLT_EXPORT FILE *win32_fopen(const char *filename_utf8, const char *mode_utf8);
+#include <sys/stat.h>
+#include <sys/types.h>
+MLT_EXPORT int win32_stat(const char *filename_utf8, struct stat *buffer);
 #include <time.h>
-extern char *strptime(const char *buf, const char *fmt, struct tm *tm);
 #define mlt_fopen win32_fopen
+#define mlt_stat win32_stat
 #define MLT_DIRLIST_DELIMITER ";"
 #else
 #define mlt_fopen fopen
+#define mlt_stat stat
 #define MLT_DIRLIST_DELIMITER ":"
 #endif /* ifdef _WIN32 */
 
-extern const char *mlt_deinterlacer_name(mlt_deinterlacer method);
-extern mlt_deinterlacer mlt_deinterlacer_id(const char *name);
+MLT_EXPORT const char *mlt_deinterlacer_name(mlt_deinterlacer method);
+MLT_EXPORT mlt_deinterlacer mlt_deinterlacer_id(const char *name);
+MLT_EXPORT mlt_color mlt_color_convert_trc(mlt_color color, const char *trc_name);
 
 #ifdef __cplusplus
 }
