@@ -1,6 +1,6 @@
 /*
  * common.h
- * Copyright (C) 2018-2024 Meltytech, LLC
+ * Copyright (C) 2018-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +26,7 @@
 
 #define MLT_AVFILTER_SWS_FLAGS "bicubic+accurate_rnd+full_chroma_int+full_chroma_inp"
 #define HAVE_FFMPEG_CH_LAYOUT (LIBAVUTIL_VERSION_MAJOR >= 59)
+#define HAVE_FFMPEG_VULKAN (LIBAVUTIL_VERSION_INT >= ((56 << 16) + (39 << 8) + 100))
 
 int mlt_to_av_sample_format(mlt_audio_format format);
 int64_t mlt_to_av_channel_layout(mlt_channel_layout layout);
@@ -50,9 +51,8 @@ int mlt_to_av_colorspace(mlt_colorspace colorspace, int height);
 mlt_colorspace av_to_mlt_colorspace(int colorspace, int width, int height);
 int mlt_to_av_color_primaries(mlt_color_primaries primaries);
 mlt_color_primaries av_to_mlt_color_primaries(int primaries);
-mlt_color_primaries mlt_color_primaries_from_colorspace(mlt_colorspace colorspace, int height);
-mlt_color_trc mlt_color_trc_from_colorspace(mlt_colorspace colorspace);
 int mlt_to_av_color_range(int full_range);
+int av_to_mlt_full_range(int color_range);
 void mlt_image_to_avframe(mlt_image image, mlt_frame mltframe, AVFrame *avframe);
 void avframe_to_mlt_image(AVFrame *avframe, mlt_image image);
 
