@@ -1,6 +1,6 @@
 /*
  * filter_avfilter.c -- provide various filters based on libavfilter
- * Copyright (C) 2016-2024 Meltytech, LLC
+ * Copyright (C) 2016-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -54,7 +54,12 @@ typedef struct
     int format;
     int width;
     int height;
+    mlt_colorspace colorspace;
+    int full_range;
     int reset;
+#if HAVE_FFMPEG_CH_LAYOUT
+    AVChannelLayout ch_layout;
+#endif
 } private_data;
 
 #if LIBAVUTIL_VERSION_INT >= ((56 << 16) + (35 << 8) + 101)
@@ -64,6 +69,14 @@ static int animatable_avoption(const AVOption *opt)
 }
 #endif
 
+int is_rgb(int format)
+{
+    if (format == mlt_image_rgb || format == mlt_image_rgba || format == mlt_image_rgba64) {
+        return 1;
+    }
+    return 0;
+}
+
 static void property_changed(mlt_service owner, mlt_filter filter, mlt_event_data event_data)
 {
     const char *name = mlt_event_data_to_string(event_data);
@@ -192,10 +205,8 @@ static void init_audio_filtergraph(mlt_filter filter,
     sample_rates[0] = frequency;
     channel_counts[0] = channels;
 #if HAVE_FFMPEG_CH_LAYOUT
-    AVChannelLayout ch_layout;
-    av_channel_layout_default(&ch_layout, channels);
-    av_channel_layout_describe(&ch_layout, channel_layout_str, sizeof(channel_layout_str));
-    av_channel_layout_uninit(&ch_layout);
+    av_channel_layout_default(&pdata->ch_layout, channels);
+    av_channel_layout_describe(&pdata->ch_layout, channel_layout_str, sizeof(channel_layout_str));
 #else
     int64_t channel_layouts[] = {-1, -1};
     channel_layouts[0] = av_get_default_channel_layout(channels);
@@ -270,6 +281,44 @@ static void init_audio_filtergraph(mlt_filter filter,
         mlt_log_error(filter, "Cannot create audio buffer sink\n");
         goto fail;
     }
+
+#if LIBAVFILTER_VERSION_INT >= ((10 << 16) + (6 << 8) + 100)
+    ret = av_opt_set_array(pdata->avbuffsink_ctx,
+                           "sample_formats",
+                           AV_OPT_SEARCH_CHILDREN,
+                           0,
+                           1,
+                           AV_OPT_TYPE_SAMPLE_FMT,
+                           sample_fmts);
+    if (ret < 0) {
+        mlt_log_error(filter, "Cannot set sink sample formats\n");
+        goto fail;
+    }
+
+    ret = av_opt_set_array(pdata->avbuffsink_ctx,
+                           "samplerates",
+                           AV_OPT_SEARCH_CHILDREN,
+                           0,
+                           1,
+                           AV_OPT_TYPE_INT,
+                           sample_rates);
+    if (ret < 0) {
+        mlt_log_error(filter, "Cannot set sink sample rates\n");
+        goto fail;
+    }
+
+    ret = av_opt_set_array(pdata->avbuffsink_ctx,
+                           "channel_layouts",
+                           AV_OPT_SEARCH_CHILDREN,
+                           0,
+                           1,
+                           AV_OPT_TYPE_CHLAYOUT,
+                           &pdata->ch_layout);
+    if (ret < 0) {
+        mlt_log_error(filter, "Cannot set sink channel layouts\n");
+        goto fail;
+    }
+#else
     ret = av_opt_set_int_list(pdata->avbuffsink_ctx,
                               "sample_fmts",
                               sample_fmts,
@@ -288,6 +337,7 @@ static void init_audio_filtergraph(mlt_filter filter,
         mlt_log_error(filter, "Cannot set sink sample rates\n");
         goto fail;
     }
+
 #if HAVE_FFMPEG_CH_LAYOUT
     ret = av_opt_set(pdata->avbuffsink_ctx,
                      "ch_layouts",
@@ -316,6 +366,7 @@ static void init_audio_filtergraph(mlt_filter filter,
         mlt_log_error(filter, "Cannot set sink channel_layouts\n");
         goto fail;
     }
+#endif
 #endif
     ret = avfilter_init_str(pdata->avbuffsink_ctx, NULL);
     if (ret < 0) {
@@ -363,8 +414,13 @@ fail:
     avfilter_graph_free(&pdata->avfilter_graph);
 }
 
-static void init_image_filtergraph(
-    mlt_filter filter, mlt_image_format format, int width, int height, double resolution_scale)
+static void init_image_filtergraph(mlt_filter filter,
+                                   mlt_image_format format,
+                                   int width,
+                                   int height,
+                                   mlt_colorspace colorspace,
+                                   int full_range,
+                                   double resolution_scale)
 {
     private_data *pdata = (private_data *) filter->child;
     mlt_profile profile = mlt_service_profile(MLT_FILTER_SERVICE(filter));
@@ -377,11 +433,15 @@ static void init_image_filtergraph(
     AVRational sar = (AVRational){profile->sample_aspect_num, profile->sample_aspect_den};
     AVRational timebase = (AVRational){profile->frame_rate_den, profile->frame_rate_num};
     AVRational framerate = (AVRational){profile->frame_rate_num, profile->frame_rate_den};
+    int avcolorspace = mlt_to_av_colorspace(colorspace, pdata->height);
+    int color_range = mlt_to_av_color_range(full_range);
     int ret;
 
     pdata->format = format;
     pdata->width = width;
     pdata->height = height;
+    pdata->colorspace = colorspace;
+    pdata->full_range = full_range;
 
     // Set up formats
     pixel_fmts[0] = mlt_to_av_image_format(format);
@@ -444,6 +504,16 @@ static void init_image_filtergraph(
         mlt_log_error(filter, "Cannot set src frame_rate %d/%d\n", framerate.num, framerate.den);
         goto fail;
     }
+    ret = av_opt_set_int(pdata->avbuffsrc_ctx, "colorspace", avcolorspace, AV_OPT_SEARCH_CHILDREN);
+    if (ret < 0) {
+        mlt_log_error(filter, "Cannot set src colorspace %d\n", avcolorspace);
+        goto fail;
+    }
+    ret = av_opt_set_int(pdata->avbuffsrc_ctx, "range", color_range, AV_OPT_SEARCH_CHILDREN);
+    if (ret < 0) {
+        mlt_log_error(filter, "Cannot set src range %d\n", color_range);
+        goto fail;
+    }
     ret = avfilter_init_str(pdata->avbuffsrc_ctx, NULL);
     if (ret < 0) {
         mlt_log_error(filter, "Cannot init buffer source\n");
@@ -456,11 +526,21 @@ static void init_image_filtergraph(
         mlt_log_error(filter, "Cannot create image buffer sink\n");
         goto fail;
     }
+#if LIBAVFILTER_VERSION_INT >= ((10 << 16) + (6 << 8) + 100)
+    ret = av_opt_set_array(pdata->avbuffsink_ctx,
+                           "pixel_formats",
+                           AV_OPT_SEARCH_CHILDREN,
+                           0,
+                           1,
+                           AV_OPT_TYPE_PIXEL_FMT,
+                           pixel_fmts);
+#else
     ret = av_opt_set_int_list(pdata->avbuffsink_ctx,
                               "pix_fmts",
                               pixel_fmts,
                               -1,
                               AV_OPT_SEARCH_CHILDREN);
+#endif
     if (ret < 0) {
         mlt_log_error(filter, "Cannot set sink pixel formats\n");
         goto fail;
@@ -777,7 +857,7 @@ static int filter_get_image(mlt_frame frame,
 
     mlt_log_debug(MLT_FILTER_SERVICE(filter), "position %" PRId64 "\n", pos);
     if (mlt_properties_get_int(MLT_FILTER_PROPERTIES(filter), "_yuv_only")) {
-        if (*format == mlt_image_rgb || *format == mlt_image_rgba)
+        if (is_rgb(*format))
             *format = mlt_image_yuv422;
     } else {
         *format = mlt_get_supported_image_format(*format);
@@ -788,10 +868,14 @@ static int filter_get_image(mlt_frame frame,
     mlt_service_lock(MLT_FILTER_SERVICE(filter));
 
     double scale = mlt_profile_scale_width(profile, *width);
+    const char *colorspace_str = mlt_properties_get(frame_properties, "colorspace");
+    mlt_colorspace colorspace = mlt_image_colorspace_id(colorspace_str);
+    int full_range = mlt_properties_get_int(frame_properties, "full_range");
 
     if (pdata->reset || pdata->format != *format || pdata->width != *width
-        || pdata->height != *height) {
-        init_image_filtergraph(filter, *format, *width, *height, scale);
+        || pdata->height != *height || pdata->colorspace != colorspace
+        || pdata->full_range != full_range) {
+        init_image_filtergraph(filter, *format, *width, *height, colorspace, full_range, scale);
         pdata->reset = 0;
     }
 
@@ -802,39 +886,40 @@ static int filter_get_image(mlt_frame frame,
         pdata->avinframe->sample_aspect_ratio = (AVRational){profile->sample_aspect_num,
                                                              profile->sample_aspect_den};
         pdata->avinframe->pts = pos;
+#if LIBAVUTIL_VERSION_INT >= ((58 << 16) + (7 << 8) + 100)
+        if (!mlt_properties_get_int(frame_properties, "progressive"))
+            pdata->avinframe->flags |= AV_FRAME_FLAG_INTERLACED;
+        else
+            pdata->avinframe->flags &= ~AV_FRAME_FLAG_INTERLACED;
+        if (mlt_properties_get_int(frame_properties, "top_field_first"))
+            pdata->avinframe->flags |= AV_FRAME_FLAG_TOP_FIELD_FIRST;
+        else
+            pdata->avinframe->flags &= ~AV_FRAME_FLAG_TOP_FIELD_FIRST;
+#else
         pdata->avinframe->interlaced_frame = !mlt_properties_get_int(frame_properties,
                                                                      "progressive");
         pdata->avinframe->top_field_first = mlt_properties_get_int(frame_properties,
                                                                    "top_field_first");
-        pdata->avinframe->color_primaries = mlt_properties_get_int(frame_properties,
-                                                                   "color_primaries");
-        pdata->avinframe->color_trc = mlt_properties_get_int(frame_properties, "color_trc");
-        // Setting full_range here causes full range input to always be down-converted to limited
-        // range when operating in YUV, regardless of the consumer.color_range -- for each avfilter!
-        // pdata->avinframe->color_range = mlt_properties_get_int(frame_properties, "full_range")
-        //                                     ? AVCOL_RANGE_JPEG
-        //                                     : AVCOL_RANGE_MPEG;
+#endif
+        const char *primaries_str = mlt_properties_get(frame_properties, "color_primaries");
+        mlt_color_primaries primaries = mlt_image_color_pri_id(primaries_str);
+        if (primaries == mlt_color_pri_none)
+            primaries = mlt_image_default_primaries(colorspace, *height);
+        pdata->avinframe->color_primaries = mlt_to_av_color_primaries(primaries);
+        const char *color_trc_str = mlt_properties_get(frame_properties, "color_trc");
+        mlt_color_trc trc = mlt_image_color_trc_id(color_trc_str);
+        if (trc == mlt_color_trc_none)
+            trc = mlt_image_default_trc(colorspace);
+        pdata->avinframe->color_trc = mlt_to_av_color_trc(trc);
+        pdata->avinframe->color_range = mlt_to_av_color_range(full_range);
 
-        if (*format == mlt_image_rgb || *format == mlt_image_rgba) {
+        if (is_rgb(*format)) {
             pdata->avinframe->colorspace = AVCOL_SPC_RGB;
         } else {
-            switch (mlt_properties_get_int(frame_properties, "colorspace")) {
-            case 240:
-                pdata->avinframe->colorspace = AVCOL_SPC_SMPTE240M;
-                break;
-            case 601:
-                pdata->avinframe->colorspace = AVCOL_SPC_BT470BG;
-                break;
-            case 709:
-                pdata->avinframe->colorspace = AVCOL_SPC_BT709;
-                break;
-            case 2020:
-                pdata->avinframe->colorspace = AVCOL_SPC_BT2020_NCL;
-                break;
-            case 2021:
-                pdata->avinframe->colorspace = AVCOL_SPC_BT2020_CL;
-                break;
-            }
+            const char *colorspace_str = mlt_properties_get(frame_properties, "colorspace");
+            mlt_colorspace colorspace = mlt_image_colorspace_id(colorspace_str);
+            pdata->avinframe->colorspace = mlt_to_av_colorspace(colorspace,
+                                                                pdata->avinframe->height);
         }
 
         ret = av_frame_get_buffer(pdata->avinframe, 1);
@@ -924,6 +1009,20 @@ static int filter_get_image(mlt_frame frame,
                 src += pdata->avoutframe->linesize[0];
             }
         }
+        mlt_properties_set_int(frame_properties,
+                               "color_trc",
+                               av_to_mlt_color_trc(pdata->avoutframe->color_trc));
+        mlt_properties_set_int(frame_properties,
+                               "colorspace",
+                               av_to_mlt_colorspace(pdata->avoutframe->colorspace,
+                                                    pdata->avoutframe->width,
+                                                    pdata->avoutframe->height));
+        mlt_properties_set_int(frame_properties,
+                               "color_primaries",
+                               av_to_mlt_color_primaries(pdata->avoutframe->color_primaries));
+        mlt_properties_set_int(frame_properties,
+                               "full_range",
+                               av_to_mlt_full_range(pdata->avoutframe->color_range));
     }
 
 exit:
@@ -962,6 +1061,9 @@ static void filter_close(mlt_filter filter)
         avfilter_graph_free(&pdata->avfilter_graph);
         av_frame_free(&pdata->avinframe);
         av_frame_free(&pdata->avoutframe);
+#if HAVE_FFMPEG_CH_LAYOUT
+        av_channel_layout_uninit(&pdata->ch_layout);
+#endif
         free(pdata);
     }
     filter->child = NULL;
