@@ -1,6 +1,6 @@
 /*
  * link_avdeinterlace.c
- * Copyright (C) 2023 Meltytech, LLC
+ * Copyright (C) 2023-2025 Meltytech, LLC
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,8 @@ typedef struct
     int outformat;
     int width;
     int height;
+    mlt_colorspace incolorspace;
+    int infullrange;
 } private_data;
 
 typedef struct
@@ -74,6 +76,7 @@ static mlt_image_format validate_format(mlt_image_format format)
     case mlt_image_yuv422p16:
     case mlt_image_yuv420p10:
     case mlt_image_yuv444p10:
+    case mlt_image_rgba64:
         ret_format = format;
         break;
     case mlt_image_none:
@@ -97,6 +100,8 @@ static void init_image_filtergraph(mlt_link self, AVRational sar)
     enum AVPixelFormat out_pixel_fmts[] = {-1, -1};
     AVRational timebase = (AVRational){profile->frame_rate_den, profile->frame_rate_num};
     AVRational framerate = (AVRational){profile->frame_rate_num, profile->frame_rate_den};
+    int colorspace = mlt_to_av_colorspace(pdata->incolorspace, pdata->height);
+    int color_range = mlt_to_av_color_range(pdata->infullrange);
     AVFilterContext *prev_ctx = NULL;
     AVFilterContext *avfilter_ctx = NULL;
     int ret;
@@ -155,6 +160,16 @@ static void init_image_filtergraph(mlt_link self, AVRational sar)
         mlt_log_error(self, "Cannot set src frame_rate %d/%d\n", framerate.num, framerate.den);
         goto fail;
     }
+    ret = av_opt_set_int(fdata->avbuffsrc_ctx, "colorspace", colorspace, AV_OPT_SEARCH_CHILDREN);
+    if (ret < 0) {
+        mlt_log_error(self, "Cannot set src colorspace %d\n", colorspace);
+        goto fail;
+    }
+    ret = av_opt_set_int(fdata->avbuffsrc_ctx, "range", color_range, AV_OPT_SEARCH_CHILDREN);
+    if (ret < 0) {
+        mlt_log_error(self, "Cannot set src range %d\n", color_range);
+        goto fail;
+    }
     ret = avfilter_init_str(fdata->avbuffsrc_ctx, NULL);
     if (ret < 0) {
         mlt_log_error(self, "Cannot init buffer source\n");
@@ -296,11 +311,21 @@ static void init_image_filtergraph(mlt_link self, AVRational sar)
         mlt_log_error(self, "Cannot create image buffer sink\n");
         goto fail;
     }
+#if LIBAVFILTER_VERSION_INT >= ((10 << 16) + (6 << 8) + 100)
+    ret = av_opt_set_array(fdata->avbuffsink_ctx,
+                           "pixel_formats",
+                           AV_OPT_SEARCH_CHILDREN,
+                           0,
+                           1,
+                           AV_OPT_TYPE_PIXEL_FMT,
+                           out_pixel_fmts);
+#else
     ret = av_opt_set_int_list(fdata->avbuffsink_ctx,
                               "pix_fmts",
                               out_pixel_fmts,
                               -1,
                               AV_OPT_SEARCH_CHILDREN);
+#endif
     if (ret < 0) {
         mlt_log_error(self, "Cannot set sink pixel formats %d\n", out_pixel_fmts[0]);
         goto fail;
@@ -376,7 +401,11 @@ static int link_get_image(mlt_frame frame,
     // Operate on the native image format/size;
     srcimg.width = mlt_properties_get_int(unique_properties, "width");
     srcimg.height = mlt_properties_get_int(unique_properties, "height");
-    srcimg.format = mlt_properties_get_int(unique_properties, "format");
+    if (mlt_properties_exists(unique_properties, "format")) {
+        srcimg.format = mlt_properties_get_int(unique_properties, "format");
+    } else {
+        srcimg.format = *format;
+    }
 
     // Sanitize the input
     if (srcimg.width <= 1 || srcimg.height <= 1) {
@@ -386,12 +415,16 @@ static int link_get_image(mlt_frame frame,
     }
     srcimg.format = validate_format(srcimg.format);
     dstimg.format = validate_format(*format);
+    const char *colorspace_str = mlt_properties_get(unique_properties, "colorspace");
+    mlt_colorspace incolorspace = mlt_image_colorspace_id(colorspace_str);
+    int infullrange = mlt_properties_get_int(unique_properties, "full_range");
 
     mlt_service_lock(MLT_LINK_SERVICE(self));
 
     if (pdata->method != method || pdata->expected_frame != mlt_frame_get_position(frame)
         || pdata->informat != srcimg.format || pdata->width != srcimg.width
-        || pdata->height != srcimg.height || pdata->outformat != dstimg.format) {
+        || pdata->height != srcimg.height || pdata->outformat != dstimg.format
+        || pdata->incolorspace != incolorspace || pdata->infullrange != infullrange) {
         mlt_log_debug(MLT_LINK_SERVICE(self),
                       "Init: %s->%s\t%d->%d\n",
                       mlt_deinterlacer_name(pdata->method),
@@ -405,6 +438,8 @@ static int link_get_image(mlt_frame frame,
         pdata->width = srcimg.width;
         pdata->height = srcimg.height;
         pdata->outformat = dstimg.format;
+        pdata->incolorspace = incolorspace;
+        pdata->infullrange = infullrange;
         init_image_filtergraph(self, av_d2q(mlt_frame_get_aspect_ratio(frame), 1024));
     }
 
@@ -452,7 +487,15 @@ static int link_get_image(mlt_frame frame,
                                         0);
             if (error || srcimg.format != pdata->informat || srcimg.width != pdata->width
                 || srcimg.height != pdata->height) {
-                mlt_log_error(MLT_LINK_SERVICE(self), "Failed to get image\n");
+                mlt_log_error(MLT_LINK_SERVICE(self),
+                              "Failed to get image\t%d\t%d=%d\t%d=%d\t%d=%d\n",
+                              error,
+                              srcimg.format,
+                              pdata->informat,
+                              srcimg.width,
+                              pdata->width,
+                              srcimg.height,
+                              pdata->height);
                 break;
             }
 
@@ -514,10 +557,49 @@ static int link_get_frame(mlt_link self, mlt_frame_ptr frame, int index)
         return error;
     }
 
+    // Pass original producer dimensions with the frame
     mlt_properties unique_properties = mlt_frame_unique_properties(*frame, MLT_LINK_SERVICE(self));
-    mlt_properties_pass_list(unique_properties,
-                             MLT_PRODUCER_PROPERTIES(original_producer),
-                             "width height format");
+    mlt_properties original_producer_properties = MLT_PRODUCER_PROPERTIES(original_producer);
+    if (mlt_properties_exists(original_producer_properties, "width")) {
+        mlt_properties_set_int(unique_properties,
+                               "width",
+                               mlt_properties_get_int(original_producer_properties, "width"));
+    } else if (mlt_properties_exists(original_producer_properties, "meta.media.width")) {
+        mlt_properties_set_int(unique_properties,
+                               "width",
+                               mlt_properties_get_int(original_producer_properties,
+                                                      "meta.media.width"));
+    }
+    if (mlt_properties_exists(original_producer_properties, "height")) {
+        mlt_properties_set_int(unique_properties,
+                               "height",
+                               mlt_properties_get_int(original_producer_properties, "height"));
+    } else if (mlt_properties_exists(original_producer_properties, "meta.media.height")) {
+        mlt_properties_set_int(unique_properties,
+                               "height",
+                               mlt_properties_get_int(original_producer_properties,
+                                                      "meta.media.height"));
+    }
+    if (mlt_properties_exists(original_producer_properties, "format")) {
+        mlt_properties_set_int(unique_properties,
+                               "format",
+                               mlt_properties_get_int(original_producer_properties, "format"));
+    }
+    if (mlt_properties_exists(original_producer_properties, "meta.media.colorspace")) {
+        mlt_properties_set(unique_properties,
+                           "colorspace",
+                           mlt_properties_get(original_producer_properties,
+                                              "meta.media.colorspace"));
+    } else if (mlt_properties_exists(MLT_FRAME_PROPERTIES(*frame), "colorspace")) {
+        mlt_properties_set(unique_properties,
+                           "colorspace",
+                           mlt_properties_get(MLT_FRAME_PROPERTIES(*frame), "colorspace"));
+    }
+    if (mlt_properties_exists(MLT_FRAME_PROPERTIES(*frame), "full_range")) {
+        mlt_properties_set(unique_properties,
+                           "full_range",
+                           mlt_properties_get(MLT_FRAME_PROPERTIES(*frame), "full_range"));
+    }
 
     // Pass future frames
     int i = 0;
