@@ -61,6 +61,9 @@ typedef struct
     int reset;
     mlt_position expected_frame;
     mlt_position continuity_frame;
+#if HAVE_FFMPEG_CH_LAYOUT
+    AVChannelLayout ch_layout;
+#endif
 } private_data;
 
 #if LIBAVUTIL_VERSION_INT >= ((56 << 16) + (35 << 8) + 101)
@@ -219,10 +222,8 @@ static void init_audio_filtergraph(mlt_link self,
     sample_rates[0] = frequency;
     channel_counts[0] = channels;
 #if HAVE_FFMPEG_CH_LAYOUT
-    AVChannelLayout ch_layout;
-    av_channel_layout_default(&ch_layout, channels);
-    av_channel_layout_describe(&ch_layout, channel_layout_str, sizeof(channel_layout_str));
-    av_channel_layout_uninit(&ch_layout);
+    av_channel_layout_default(&pdata->ch_layout, channels);
+    av_channel_layout_describe(&pdata->ch_layout, channel_layout_str, sizeof(channel_layout_str));
 #else
     int64_t channel_layouts[] = {-1, -1};
     channel_layouts[0] = av_get_default_channel_layout(channels);
@@ -297,6 +298,44 @@ static void init_audio_filtergraph(mlt_link self,
         mlt_log_error(self, "Cannot create audio buffer sink\n");
         goto fail;
     }
+
+#if LIBAVFILTER_VERSION_INT >= ((10 << 16) + (6 << 8) + 100)
+    ret = av_opt_set_array(pdata->avbuffsink_ctx,
+                           "sample_formats",
+                           AV_OPT_SEARCH_CHILDREN,
+                           0,
+                           1,
+                           AV_OPT_TYPE_SAMPLE_FMT,
+                           sample_fmts);
+    if (ret < 0) {
+        mlt_log_error(self, "Cannot set sink sample formats\n");
+        goto fail;
+    }
+
+    ret = av_opt_set_array(pdata->avbuffsink_ctx,
+                           "samplerates",
+                           AV_OPT_SEARCH_CHILDREN,
+                           0,
+                           1,
+                           AV_OPT_TYPE_INT,
+                           sample_rates);
+    if (ret < 0) {
+        mlt_log_error(self, "Cannot set sink sample rates\n");
+        goto fail;
+    }
+
+    ret = av_opt_set_array(pdata->avbuffsink_ctx,
+                           "channel_layouts",
+                           AV_OPT_SEARCH_CHILDREN,
+                           0,
+                           1,
+                           AV_OPT_TYPE_CHLAYOUT,
+                           &pdata->ch_layout);
+    if (ret < 0) {
+        mlt_log_error(self, "Cannot set sink channel layouts\n");
+        goto fail;
+    }
+#else
     ret = av_opt_set_int_list(pdata->avbuffsink_ctx,
                               "sample_fmts",
                               sample_fmts,
@@ -343,6 +382,7 @@ static void init_audio_filtergraph(mlt_link self,
         mlt_log_error(self, "Cannot set sink channel_layouts\n");
         goto fail;
     }
+#endif
 #endif
     ret = avfilter_init_str(pdata->avbuffsink_ctx, NULL);
     if (ret < 0) {
@@ -967,13 +1007,13 @@ static int link_get_image(mlt_frame frame,
         const char *primaries_str = mlt_properties_get(frame_properties, "color_primaries");
         mlt_color_primaries primaries = mlt_image_color_pri_id(primaries_str);
         if (primaries == mlt_color_pri_none)
-            primaries = mlt_color_primaries_from_colorspace(colorspace, *height);
+            primaries = mlt_image_default_primaries(colorspace, *height);
         pdata->avinframe->color_primaries = mlt_to_av_color_primaries(primaries);
         const char *color_trc_str = mlt_properties_get(frame_properties, "color_trc");
         mlt_color_trc trc = mlt_image_color_trc_id(color_trc_str);
         pdata->avinframe->color_trc = mlt_to_av_color_trc(trc);
         if (trc == mlt_color_trc_none)
-            trc = mlt_color_trc_from_colorspace(colorspace);
+            trc = mlt_image_default_trc(colorspace);
         pdata->avinframe->color_range = mlt_to_av_color_range(full_range);
         const char *colorspace_str = mlt_properties_get(frame_properties, "colorspace");
         mlt_colorspace colorspace = mlt_image_colorspace_id(colorspace_str);
@@ -1054,6 +1094,20 @@ static int link_get_image(mlt_frame frame,
                 src += pdata->avoutframe->linesize[0];
             }
         }
+        mlt_properties_set_int(frame_properties,
+                               "color_trc",
+                               av_to_mlt_color_trc(pdata->avoutframe->color_trc));
+        mlt_properties_set_int(frame_properties,
+                               "colorspace",
+                               av_to_mlt_colorspace(pdata->avoutframe->colorspace,
+                                                    pdata->avoutframe->width,
+                                                    pdata->avoutframe->height));
+        mlt_properties_set_int(frame_properties,
+                               "color_primaries",
+                               av_to_mlt_color_primaries(pdata->avoutframe->color_primaries));
+        mlt_properties_set_int(frame_properties,
+                               "full_range",
+                               av_to_mlt_full_range(pdata->avoutframe->color_range));
     }
 
 exit:
@@ -1115,6 +1169,9 @@ static void link_close(mlt_link self)
             avfilter_graph_free(&pdata->avfilter_graph);
             av_frame_free(&pdata->avinframe);
             av_frame_free(&pdata->avoutframe);
+#if HAVE_FFMPEG_CH_LAYOUT
+            av_channel_layout_uninit(&pdata->ch_layout);
+#endif
             free(pdata);
         }
         self->close = NULL;
