@@ -1,6 +1,6 @@
 /*
  * factory.c -- the factory method interfaces
- * Copyright (C) 2003-2023 Meltytech, LLC
+ * Copyright (C) 2003-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,10 +17,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include "mltcore_export.h"
 #include <framework/mlt.h>
 #include <limits.h>
 #include <string.h>
-
 extern mlt_consumer consumer_multi_init(mlt_profile profile,
                                         mlt_service_type type,
                                         const char *id,
@@ -65,6 +65,10 @@ extern mlt_filter filter_choppy_init(mlt_profile profile,
                                      mlt_service_type type,
                                      const char *id,
                                      char *arg);
+extern mlt_filter filter_color_transform_init(mlt_profile profile,
+                                              mlt_service_type type,
+                                              const char *id,
+                                              char *arg);
 extern mlt_filter filter_crop_init(mlt_profile profile,
                                    mlt_service_type type,
                                    const char *id,
@@ -202,10 +206,11 @@ static mlt_properties metadata(mlt_service_type type, const char *id, void *data
     return mlt_properties_parse_yaml(file);
 }
 
-MLT_REPOSITORY
+MLTCORE_EXPORT MLT_REPOSITORY
 {
     MLT_REGISTER(mlt_service_consumer_type, "multi", consumer_multi_init);
     MLT_REGISTER(mlt_service_consumer_type, "null", consumer_null_init);
+    MLT_REGISTER(mlt_service_link_type, "color_transform", mlt_link_filter_init);
     MLT_REGISTER(mlt_service_filter_type, "audiochannels", filter_audiochannels_init);
     MLT_REGISTER(mlt_service_filter_type, "audioconvert", filter_audioconvert_init);
     MLT_REGISTER(mlt_service_filter_type, "audiomap", filter_audiomap_init);
@@ -217,6 +222,7 @@ MLT_REPOSITORY
     MLT_REGISTER(mlt_service_filter_type, "channelcopy", filter_channelcopy_init);
     MLT_REGISTER(mlt_service_filter_type, "channelswap", filter_channelcopy_init);
     MLT_REGISTER(mlt_service_filter_type, "choppy", filter_choppy_init);
+    MLT_REGISTER(mlt_service_filter_type, "color_transform", filter_color_transform_init);
     MLT_REGISTER(mlt_service_filter_type, "crop", filter_crop_init);
     MLT_REGISTER(mlt_service_filter_type, "fieldorder", filter_fieldorder_init);
     MLT_REGISTER(mlt_service_filter_type, "gamma", filter_gamma_init);
@@ -263,6 +269,7 @@ MLT_REPOSITORY
 
     MLT_REGISTER_METADATA(mlt_service_consumer_type, "multi", metadata, "consumer_multi.yml");
     MLT_REGISTER_METADATA(mlt_service_consumer_type, "null", metadata, "consumer_null.yml");
+    MLT_REGISTER_METADATA(mlt_service_link_type, "color_transform", mlt_link_filter_metadata, NULL);
     MLT_REGISTER_METADATA(mlt_service_filter_type,
                           "audiochannels",
                           metadata,
@@ -286,6 +293,10 @@ MLT_REPOSITORY
                           metadata,
                           "filter_channelcopy.yml");
     MLT_REGISTER_METADATA(mlt_service_filter_type, "choppy", metadata, "filter_choppy.yml");
+    MLT_REGISTER_METADATA(mlt_service_filter_type,
+                          "color_transform",
+                          metadata,
+                          "filter_color_transform.yml");
     MLT_REGISTER_METADATA(mlt_service_filter_type, "crop", metadata, "filter_crop.yml");
     MLT_REGISTER_METADATA(mlt_service_filter_type, "fieldorder", metadata, "filter_fieldorder.yml");
     MLT_REGISTER_METADATA(mlt_service_filter_type, "gamma", metadata, "filter_gamma.yml");
