@@ -1,6 +1,6 @@
 /*
  * filter_mono.c -- mix all channels to a mono signal across n channels
- * Copyright (C) 2003-2018 Meltytech, LLC
+ * Copyright (C) 2003-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 /** Get the audio.
 */
@@ -34,87 +35,119 @@ static int filter_get_audio(mlt_frame frame,
                             int *channels,
                             int *samples)
 {
-    // Get the properties of the a frame
-    mlt_properties properties = MLT_FRAME_PROPERTIES(frame);
-    int channels_out = mlt_properties_get_int(properties, "mono.channels");
+    mlt_filter filter = (mlt_filter) mlt_frame_pop_audio(frame);
+    mlt_properties properties = mlt_filter_properties(filter);
+    int channels_out = mlt_properties_get_int(properties, "channels");
+    int input_chmask = mlt_properties_get_int64(properties, "input_chmask");
+    int output_chmask = mlt_properties_get_int64(properties, "output_chmask");
     int i, j, size;
 
     // Get the producer's audio
     mlt_frame_get_audio(frame, buffer, format, frequency, channels, samples);
 
-    if (channels_out == -1)
+    if (channels_out == -1 || channels_out > *channels)
         channels_out = *channels;
     size = mlt_audio_format_size(*format, *samples, channels_out);
 
     switch (*format) {
     case mlt_audio_u8: {
         uint8_t *new_buffer = mlt_pool_alloc(size);
+        memcpy(new_buffer, *buffer, size);
         for (i = 0; i < *samples; i++) {
             uint8_t mixdown = 0;
-            for (j = 0; j < *channels; j++)
-                mixdown += ((uint8_t *) *buffer)[(i * *channels) + j];
-            for (j = 0; j < channels_out; j++)
-                new_buffer[(i * channels_out) + j] = mixdown;
+            for (j = 0; j < *channels; j++) {
+                if (input_chmask & (1 << j))
+                    mixdown += ((uint8_t *) *buffer)[(i * *channels) + j];
+            }
+            for (j = 0; j < channels_out; j++) {
+                if (output_chmask & (1 << j))
+                    new_buffer[(i * channels_out) + j] = mixdown;
+            }
         }
         *buffer = new_buffer;
         break;
     }
     case mlt_audio_s16: {
         int16_t *new_buffer = mlt_pool_alloc(size);
+        memcpy(new_buffer, *buffer, size);
         for (i = 0; i < *samples; i++) {
             int16_t mixdown = 0;
-            for (j = 0; j < *channels; j++)
-                mixdown += ((int16_t *) *buffer)[(i * *channels) + j];
-            for (j = 0; j < channels_out; j++)
-                new_buffer[(i * channels_out) + j] = mixdown;
+            for (j = 0; j < *channels; j++) {
+                if (input_chmask & (1 << j))
+                    mixdown += ((int16_t *) *buffer)[(i * *channels) + j];
+            }
+            for (j = 0; j < channels_out; j++) {
+                if (output_chmask & (1 << j))
+                    new_buffer[(i * channels_out) + j] = mixdown;
+            }
         }
         *buffer = new_buffer;
         break;
     }
     case mlt_audio_s32le: {
         int32_t *new_buffer = mlt_pool_alloc(size);
+        memcpy(new_buffer, *buffer, size);
         for (i = 0; i < *samples; i++) {
             int32_t mixdown = 0;
-            for (j = 0; j < *channels; j++)
-                mixdown += ((int32_t *) *buffer)[(i * *channels) + j];
-            for (j = 0; j < channels_out; j++)
-                new_buffer[(i * channels_out) + j] = mixdown;
+            for (j = 0; j < *channels; j++) {
+                if (input_chmask & (1 << j))
+                    mixdown += ((int32_t *) *buffer)[(i * *channels) + j];
+            }
+            for (j = 0; j < channels_out; j++) {
+                if (output_chmask & (1 << j))
+                    new_buffer[(i * channels_out) + j] = mixdown;
+            }
         }
         *buffer = new_buffer;
         break;
     }
     case mlt_audio_f32le: {
         float *new_buffer = mlt_pool_alloc(size);
+        memcpy(new_buffer, *buffer, size);
         for (i = 0; i < *samples; i++) {
             float mixdown = 0;
-            for (j = 0; j < *channels; j++)
-                mixdown += ((float *) *buffer)[(i * *channels) + j];
-            for (j = 0; j < channels_out; j++)
-                new_buffer[(i * channels_out) + j] = mixdown;
+            for (j = 0; j < *channels; j++) {
+                if (input_chmask & (1 << j))
+                    mixdown += ((float *) *buffer)[(i * *channels) + j];
+            }
+            for (j = 0; j < channels_out; j++) {
+                if (output_chmask & (1 << j))
+                    new_buffer[(i * channels_out) + j] = mixdown;
+            }
         }
         *buffer = new_buffer;
         break;
     }
     case mlt_audio_s32: {
         int32_t *new_buffer = mlt_pool_alloc(size);
+        memcpy(new_buffer, *buffer, size);
         for (i = 0; i < *samples; i++) {
             int32_t mixdown = 0;
-            for (j = 0; j < *channels; j++)
-                mixdown += ((int32_t *) *buffer)[(j * *samples) + i];
-            for (j = 0; j < channels_out; j++)
-                new_buffer[(j * *samples) + i] = mixdown;
+            for (j = 0; j < *channels; j++) {
+                if (input_chmask & (1 << j))
+                    mixdown += ((int32_t *) *buffer)[(j * *samples) + i];
+            }
+            for (j = 0; j < channels_out; j++) {
+                if (output_chmask & (1 << j))
+                    new_buffer[(j * *samples) + i] = mixdown;
+            }
         }
         *buffer = new_buffer;
         break;
     }
     case mlt_audio_float: {
         float *new_buffer = mlt_pool_alloc(size);
+        memcpy(new_buffer, *buffer, size);
         for (i = 0; i < *samples; i++) {
             float mixdown = 0;
-            for (j = 0; j < *channels; j++)
-                mixdown += ((float *) *buffer)[(j * *samples) + i];
-            for (j = 0; j < channels_out; j++)
-                new_buffer[(j * *samples) + i] = mixdown;
+            for (j = 0; j < *channels; j++) {
+                if (input_chmask & (1 << j))
+                    mixdown += ((float *) *buffer)[(j * *samples) + i];
+            }
+            for (j = 0; j < channels_out; j++) {
+                if (output_chmask & (1 << j))
+                    new_buffer[(j * *samples) + i] = mixdown;
+            }
         }
         *buffer = new_buffer;
         break;
@@ -136,15 +169,8 @@ static int filter_get_audio(mlt_frame frame,
 
 static mlt_frame filter_process(mlt_filter filter, mlt_frame frame)
 {
-    mlt_properties properties = MLT_FILTER_PROPERTIES(filter);
-    mlt_properties frame_props = MLT_FRAME_PROPERTIES(frame);
-
-    // Propagate the parameters
-    mlt_properties_set_int(frame_props,
-                           "mono.channels",
-                           mlt_properties_get_int(properties, "channels"));
-
     // Override the get_audio method
+    mlt_frame_push_audio(frame, filter);
     mlt_frame_push_audio(frame, filter_get_audio);
 
     return frame;
@@ -162,6 +188,8 @@ mlt_filter filter_mono_init(mlt_profile profile, mlt_service_type type, const ch
             mlt_properties_set_int(MLT_FILTER_PROPERTIES(filter), "channels", atoi(arg));
         else
             mlt_properties_set_int(MLT_FILTER_PROPERTIES(filter), "channels", -1);
+        mlt_properties_set_int(MLT_FILTER_PROPERTIES(filter), "input_chmask", 7);
+        mlt_properties_set_int(MLT_FILTER_PROPERTIES(filter), "output_chmask", -1);
     }
     return filter;
 }
