@@ -113,8 +113,10 @@ static void change_movit_format(mlt_frame frame, mlt_frame src_frame, mlt_image_
         } else {
             // Use a 10-bit output if the end consumer wants it.
             // TODO add a "consumer.format" property to find other criteria for 10-bit
-            const char *trc = mlt_properties_get(MLT_FRAME_PROPERTIES(frame), "consumer.color_trc");
-            *format = (trc && !strcmp("arib-std-b67", trc)) ? mlt_image_yuv444p10 : mlt_image_rgba;
+            const char *trc_str = mlt_properties_get(MLT_FRAME_PROPERTIES(frame),
+                                                     "consumer.color_trc");
+            mlt_color_trc trc = mlt_image_color_trc_id(trc_str);
+            *format = trc == mlt_color_trc_arib_std_b67 ? mlt_image_yuv444p10 : mlt_image_rgba;
         }
     }
 }
@@ -342,6 +344,8 @@ static int link_get_audio(mlt_frame frame,
     return error;
 }
 
+#define MAX_BLEND_IMAGES 10
+
 static int link_get_image_blend(mlt_frame frame,
                                 uint8_t **image,
                                 mlt_image_format *format,
@@ -349,7 +353,6 @@ static int link_get_image_blend(mlt_frame frame,
                                 int *height,
                                 int writable)
 {
-    static const int MAX_BLEND_IMAGES = 10;
     mlt_link self = (mlt_link) mlt_frame_pop_get_image(frame);
     mlt_properties unique_properties = mlt_frame_get_unique_properties(frame,
                                                                        MLT_LINK_SERVICE(self));
@@ -403,8 +406,15 @@ static int link_get_image_blend(mlt_frame frame,
                           *height);
             break;
         }
-        in_frame_pos++;
         image_count++;
+        in_frame_pos++;
+        sprintf(key, "%d", in_frame_pos);
+        mlt_frame next_frame = mlt_properties_get_data(unique_properties, key, NULL);
+        if (next_frame) {
+            src_frame = next_frame;
+        } else {
+            break;
+        }
     }
 
     if (image_count <= 0) {
@@ -416,16 +426,29 @@ static int link_get_image_blend(mlt_frame frame,
     int size = mlt_image_format_size(*format, *width, *height, NULL);
     *image = mlt_pool_alloc(size);
     int s = 0;
-    uint8_t *p = *image;
-    for (s = 0; s < size; s++) {
-        int16_t sum = 0;
-        int i = 0;
-        for (i = 0; i < image_count; i++) {
-            sum += *(images[i]);
-            images[i]++;
+    if (*format == mlt_image_rgba64) {
+        uint16_t *p = (uint16_t *) *image;
+        size /= 2;
+        for (s = 0; s < size; s++) {
+            int32_t sum = 0;
+            for (int i = 0; i < image_count; i++) {
+                uint16_t *image16 = (uint16_t *) images[i];
+                sum += image16[s];
+            }
+            p[s] = sum / image_count;
+        }
+    } else {
+        uint8_t *p = *image;
+        for (s = 0; s < size; s++) {
+            int16_t sum = 0;
+            int i = 0;
+            for (i = 0; i < image_count; i++) {
+                sum += *(images[i]);
+                images[i]++;
+            }
+            *p = sum / image_count;
+            p++;
         }
-        *p = sum / image_count;
-        p++;
     }
     mlt_frame_set_image(frame, *image, size, mlt_pool_release);
     mlt_properties_set_int(MLT_FRAME_PROPERTIES(frame), "format", *format);
