@@ -204,7 +204,7 @@ static int dissolve_slice_rgba32(int id, int index, int count, void *context)
                 mix_b /= mix2;
             dst[0] = sample_mix(dst[0], src[0], mix_b);
             dst[1] = sample_mix(dst[1], src[1], mix_b);
-            dst[2] = sample_mix(dst[2], src[1], mix_b);
+            dst[2] = sample_mix(dst[2], src[2], mix_b);
             dst[3] = 255 * mix2;
             dst += 4;
             src += 4;
@@ -255,7 +255,7 @@ static int dissolve_slice_rgba64(int id, int index, int count, void *context)
                 mix_b /= mix2;
             dst[0] = sample_mix_16(dst[0], src[0], mix_b);
             dst[1] = sample_mix_16(dst[1], src[1], mix_b);
-            dst[2] = sample_mix_16(dst[2], src[1], mix_b);
+            dst[2] = sample_mix_16(dst[2], src[2], mix_b);
             dst[3] = 255 * mix2;
             dst += 4;
             src += 4;
@@ -992,6 +992,16 @@ static int transition_get_image(mlt_frame a_frame,
             mlt_properties_set(&b_frame->parent,
                                "distort",
                                mlt_properties_get(&a_frame->parent, "distort"));
+
+        if (mlt_color_trc_linear
+            == mlt_image_color_trc_id(mlt_properties_get(a_props, "consumer.mlt_color_trc"))) {
+            // Make progress appear linear using a gamma curve similar to sRGB or Rec. 709
+            if (reverse || invert)
+                mix = 1.0 - pow(1.0 - mix, 2.0);
+            else
+                mix = pow(mix, 2.0);
+        }
+
         mix = (reverse || invert) ? 1 - mix : mix;
         invert = 0;
         // Dissolve the frames using the time offset for mix value
