@@ -17,26 +17,30 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include "frei0r_helper.h"
 #include <framework/mlt_filter.h>
 #include <framework/mlt_frame.h>
-#include "frei0r_helper.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 
-static mlt_frame filter_process( mlt_filter filter, mlt_frame frame )
+static mlt_frame filter_process(mlt_filter filter, mlt_frame frame)
 {
-	mlt_properties_set(MLT_FRAME_PROPERTIES(frame), CAIROBLEND_MODE_PROPERTY,
-		mlt_properties_get(MLT_FILTER_PROPERTIES(filter), "mode"));
-	return frame;
+    mlt_properties_set(MLT_FRAME_PROPERTIES(frame),
+                       CAIROBLEND_MODE_PROPERTY,
+                       mlt_properties_get(MLT_FILTER_PROPERTIES(filter), "mode"));
+    return frame;
 }
 
-mlt_filter filter_cairoblend_mode_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg )
+mlt_filter filter_cairoblend_mode_init(mlt_profile profile,
+                                       mlt_service_type type,
+                                       const char *id,
+                                       char *arg)
 {
-	mlt_filter filter = mlt_filter_new( );
-	if (filter)	{
-		filter->process = filter_process;
-		mlt_properties_set(MLT_FILTER_PROPERTIES( filter ), "mode", arg? arg : "normal");
-	}
-	return filter;
+    mlt_filter filter = mlt_filter_new();
+    if (filter) {
+        filter->process = filter_process;
+        mlt_properties_set(MLT_FILTER_PROPERTIES(filter), "mode", arg ? arg : "normal");
+    }
+    return filter;
 }
