@@ -20,13 +20,13 @@ public:
     QStringList extensions() const override { return {"tgs"}; }
     bool can_save() const override { return true; }
     bool can_open() const override { return true; }
-    std::unique_ptr<app::settings::SettingsGroup> save_settings(model::Document*) const override { return {}; }
+    std::unique_ptr<app::settings::SettingsGroup> save_settings(model::Composition*) const override { return {}; }
 
-    void validate(model::Document* document);
+    void validate(model::Document* document, model::Composition* comp);
 
 private:
     bool on_save(QIODevice& file, const QString&,
-                 model::Document* document, const QVariantMap&) override;
+                 model::Composition* comp, const QVariantMap&) override;
 
     bool on_open(QIODevice& file, const QString&,
                  model::Document* document, const QVariantMap&) override;
