@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2019-2023 Mattia Basaglia <dev@dragon.best>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ */
+
 #pragma once
 
 #include <QJsonDocument>
@@ -25,7 +31,7 @@ public:
     QJsonDocument to_json(const QByteArray& binary_data);
 
 protected:
-    bool on_save(QIODevice& file, const QString&, model::Document* document, const QVariantMap&) override;
+    bool on_save(QIODevice& file, const QString&, model::Composition* comp, const QVariantMap&) override;
     bool on_open(QIODevice& file, const QString&, model::Document* document, const QVariantMap&) override;
 
 private:
