@@ -25,16 +25,19 @@ bool glaxnimate::io::svg::SvgFormat::on_open(QIODevice& file, const QString& fil
     try
     {
         QSize forced_size = options["forced_size"].toSize();
+        model::FrameTime default_time = options["default_time"].toFloat();
+
+        auto default_asset_path = QFileInfo(filename).dir();
 
         if ( utils::gzip::is_compressed(file) )
         {
             utils::gzip::GzipStream decompressed(&file, on_error);
             decompressed.open(QIODevice::ReadOnly);
-            SvgParser(&decompressed, mode, document, on_error, this, forced_size).parse_to_document();
+            SvgParser(&decompressed, mode, document, on_error, this, forced_size, default_time, default_asset_path).parse_to_document();
             return true;
         }
 
-        SvgParser(&file, mode, document, on_error, this, forced_size).parse_to_document();
+        SvgParser(&file, mode, document, on_error, this, forced_size, default_time, default_asset_path).parse_to_document();
         return true;
 
     }
@@ -45,10 +48,10 @@ bool glaxnimate::io::svg::SvgFormat::on_open(QIODevice& file, const QString& fil
     }
 }
 
-std::unique_ptr<app::settings::SettingsGroup> glaxnimate::io::svg::SvgFormat::save_settings(model::Document* document) const
+std::unique_ptr<app::settings::SettingsGroup> glaxnimate::io::svg::SvgFormat::save_settings(model::Composition* comp) const
 {
     CssFontType max = CssFontType::None;
-    for ( const auto & font : document->assets()->fonts->values )
+    for ( const auto & font : comp->document()->assets()->fonts->values )
     {
         auto type = SvgRenderer::suggested_type(font.get());
         if ( type > max )
@@ -73,11 +76,11 @@ std::unique_ptr<app::settings::SettingsGroup> glaxnimate::io::svg::SvgFormat::sa
     });
 }
 
-bool glaxnimate::io::svg::SvgFormat::on_save(QIODevice& file, const QString& filename, model::Document* document, const QVariantMap& options)
+bool glaxnimate::io::svg::SvgFormat::on_save(QIODevice& file, const QString& filename, model::Composition* comp, const QVariantMap& options)
 {
     auto on_error = [this](const QString& s){warning(s);};
     SvgRenderer rend(SMIL, CssFontType(options["font_type"].toInt()));
-    rend.write_document(document);
+    rend.write_main(comp);
     if ( filename.endsWith(".svgz") || options.value("compressed", false).toBool() )
     {
         utils::gzip::GzipStream compressed(&file, on_error);
