@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 Dan Dennedy <dan@dennedy.org>
+ * Copyright (C) 2014-2025 Dan Dennedy <dan@dennedy.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,8 +24,15 @@
 class QImage;
 
 bool createQApplicationIfNeeded(mlt_service service);
-void convert_qimage_to_mlt_rgba( QImage* qImg, uint8_t* mImg, int width, int height );
-void convert_mlt_to_qimage_rgba( uint8_t* mImg, QImage* qImg, int width, int height );
-int create_image( mlt_frame frame, uint8_t **image, mlt_image_format *image_format, int *width, int *height, int writable );
+mlt_image_format choose_image_format(mlt_image_format format);
+void convert_qimage_to_mlt(QImage *qImg, uint8_t *mImg, int width, int height);
+void convert_mlt_to_qimage(
+    uint8_t *mImg, QImage *qImg, int width, int height, mlt_image_format format);
+int create_image(mlt_frame frame,
+                 uint8_t **image,
+                 mlt_image_format *image_format,
+                 int *width,
+                 int *height,
+                 int writable);
 
 #endif // COMMON_H
