@@ -1,6 +1,6 @@
 /*
  * filter_gpsgraphic.cpp -- draws gps related graphics
- * Copyright (c) 2015-2022 Meltytech, LLC
+ * Copyright (c) 2015-2025 Meltytech, LLC
  * Original author: Daniel F
  *
  * This library is free software; you can redistribute it and/or
@@ -130,20 +130,20 @@ double get_by_src(mlt_filter filter,
     if (pdata->graph_data_source == gspg_location_src) {
         if (get_type == -1) {
             if (subtype == gpsg_latitude_id)
-                return pdata->minmax.min_lat;
+                return pdata->minmax.min_lat_projected;
             else if (subtype == gpsg_longitude_id)
                 return pdata->minmax.min_lon;
         } else if (get_type == 1) {
             if (subtype == gpsg_latitude_id)
-                return pdata->minmax.max_lat;
+                return pdata->minmax.max_lat_projected;
             else if (subtype == gpsg_longitude_id)
                 return pdata->minmax.max_lon;
         } else if (get_type == 0) {
             if (subtype == gpsg_latitude_id) {
                 if (gps_p == NULL)
-                    return pdata->gps_points_p[i_gps].lat;
+                    return pdata->gps_points_p[i_gps].lat_projected;
                 else if (gps_p != NULL)
-                    return gps_p->lat;
+                    return gps_p->lat_projected;
             } else if (subtype == gpsg_longitude_id) {
                 if (gps_p == NULL)
                     return pdata->gps_points_p[i_gps].lon;
@@ -401,16 +401,16 @@ static int filter_get_image(mlt_frame frame,
     s_base_crops used_crops = {0, 100, 0, 100};
 
     // Get the current image
-    *format = mlt_image_rgba;
+    *format = choose_image_format(*format);
     error = mlt_frame_get_image(frame, image, format, width, height, writable);
 
     // Draw the graph
     if (!error) {
         process_frame_properties(filter, frame, used_crops);
-        QImage qimg(*width, *height, QImage::Format_ARGB32);
-        convert_mlt_to_qimage_rgba(*image, &qimg, *width, *height);
+        QImage qimg;
+        convert_mlt_to_qimage(*image, &qimg, *width, *height, *format);
         draw_graphics(filter, frame, &qimg, *width, *height, used_crops);
-        convert_qimage_to_mlt_rgba(&qimg, *image, *width, *height);
+        convert_qimage_to_mlt(&qimg, *image, *width, *height);
     } else
         mlt_log_warning(MLT_FILTER_SERVICE(filter),
                         "mlt_frame_get_image error=%d, can't draw at all\n",
@@ -485,34 +485,23 @@ static void find_minmax_of_data(mlt_filter filter)
         assign_if_smaller(crt->grade_p, pdata->minmax.min_grade_p);
         assign_if_bigger(crt->grade_p, pdata->minmax.max_grade_p);
     }
+    pdata->minmax.min_lat_projected = project_latitude(pdata->minmax.min_lat);
+    pdata->minmax.max_lat_projected = project_latitude(pdata->minmax.max_lat);
 #undef assign_if_smaller
 #undef assign_if_bigger
 
-    //compute the map aspect ratio using real distances (used to correctly overlay background image over gps track)
+    //compute the gps track aspect ratio (from coords)
     double map_aspect_ratio = 1;
-    double map_width = distance_haversine_2p(pdata->minmax.min_lat,
-                                             pdata->minmax.min_lon,
-                                             pdata->minmax.min_lat,
-                                             pdata->minmax.max_lon);
-    double map_height = distance_haversine_2p(pdata->minmax.min_lat,
-                                              pdata->minmax.min_lon,
-                                              pdata->minmax.max_lat,
-                                              pdata->minmax.min_lon);
-    if (map_width && map_height)
+    double map_width = pdata->minmax.max_lon - pdata->minmax.min_lon;
+    double map_height = pdata->minmax.max_lat_projected - pdata->minmax.min_lat_projected;
+    if (map_width && map_height) {
         map_aspect_ratio = map_width / map_height;
-    pdata->map_aspect_ratio_from_distance = map_aspect_ratio;
+        pdata->map_aspect_ratio_from_distance = map_aspect_ratio;
+    }
     mlt_properties_set_double(MLT_FILTER_PROPERTIES(filter),
                               "map_original_aspect_ratio",
                               map_aspect_ratio);
 
-    // //compute the gps track aspect ratio (from coords) // the other one seems better almost every time
-    // map_aspect_ratio = 1;
-    // map_width = pdata->minmax.max_lon - pdata->minmax.min_lon;
-    // map_height = pdata->minmax.max_lat - pdata->minmax.min_lat;
-    // if (map_width && map_height)
-    // 	map_aspect_ratio = map_width / map_height;
-    // mlt_properties_set_double(MLT_FILTER_PROPERTIES( filter ), "map_original_aspect_ratio", map_aspect_ratio);
-
     char middle_point[255];
     double middle_lat = (pdata->minmax.min_lat + pdata->minmax.max_lat) / 2;
     double middle_lon = (pdata->minmax.min_lon + pdata->minmax.max_lon) / 2;
@@ -639,7 +628,7 @@ static void process_filter_properties(mlt_filter filter, mlt_frame frame)
                                                     new_bg_height,
                                                     Qt::IgnoreAspectRatio,
                                                     Qt::SmoothTransformation);
-        // mlt_log_info(filter, "scaled image= x,y w,h= %d,%d %d,%d", pdata->bg_img_scaled.rect().x(), pdata->bg_img_scaled.rect().y(), pdata->bg_img_scaled.rect().width(), pdata->bg_img_scaled.rect().height());
+        // mlt_log_info(filter, "scaled image= x,y w,h= %d,%d %d,%d\n", pdata->bg_img_scaled.rect().x(), pdata->bg_img_scaled.rect().y(), pdata->bg_img_scaled.rect().width(), pdata->bg_img_scaled.rect().height());
         // pdata->bg_img_scaled.save("qimage_saved02_scaled_by_mapAR.jpg");
 
         //next steps are in prepare_canvas() as they depend on each frame position (used_crops)
@@ -673,7 +662,7 @@ static void process_file(mlt_filter filter, mlt_frame frame)
 
     //check if the file has been changed, if not, current data is ok, do nothing
     if (strcmp(pdata->last_filename, filename)) {
-        // mlt_log_info(filter, "Reading new file: last_filename (%s) != entered_filename (%s), swap_180 = %d \n", pdata->last_filename, filename, swap);
+        // mlt_log_info(filter, "Reading new file: last_filename (%s) != entered_filename (%s), swap_180 = %d\n", pdata->last_filename, filename, swap);
         default_priv_data(pdata);
         strcpy(pdata->last_filename, filename);
 
