@@ -1,6 +1,6 @@
 /*
  * filter_qtext.cpp -- text overlay filter
- * Copyright (c) 2018-2021 Meltytech, LLC
+ * Copyright (c) 2018-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,14 +31,130 @@
 #include <QtCore5Compat/QTextCodec>
 #endif
 
+#include "typewriter.h"
+#include <string>
 #include <QMutexLocker>
 
 static QMutex g_mutex;
 
+struct TypewriterFilterData
+{
+    TypeWriter typewriter;
+    std::string original_text;
+    int macro_type;
+
+    TypewriterFilterData() {}
+};
+
+static void close_typewriter_filter_data(void *data)
+{
+    delete static_cast<TypewriterFilterData *>(data);
+}
+
+static std::string get_typewriter_text_for_filter(mlt_properties filter_properties,
+                                                  const char *original_text,
+                                                  mlt_position position)
+{
+    if (!mlt_properties_get_int(filter_properties, "typewriter") || !original_text) {
+        return original_text ? std::string(original_text) : std::string("");
+    }
+
+    auto *tw_data = static_cast<TypewriterFilterData *>(
+        mlt_properties_get_data(filter_properties, "_typewriter_filter_data", NULL));
+
+    if (!tw_data) {
+        tw_data = new TypewriterFilterData();
+        mlt_properties_set_data(filter_properties,
+                                "_typewriter_filter_data",
+                                static_cast<void *>(tw_data),
+                                0,
+                                close_typewriter_filter_data,
+                                NULL);
+    }
+
+    auto text_str = std::string(original_text);
+    unsigned int step_length = mlt_properties_get_int(filter_properties, "typewriter.step_length");
+    unsigned int step_sigma = mlt_properties_get_int(filter_properties, "typewriter.step_sigma");
+    unsigned int random_seed = mlt_properties_get_int(filter_properties, "typewriter.random_seed");
+    int macro_type = mlt_properties_get_int(filter_properties, "typewriter.macro_type");
+
+    // Check if text or typewriter settings changed
+    if (tw_data->original_text != text_str || tw_data->typewriter.getFrameStep() != step_length
+        || tw_data->typewriter.getStepSigma() != step_sigma
+        || tw_data->typewriter.getStepSeed() != random_seed || tw_data->macro_type != macro_type) {
+        tw_data->original_text = text_str;
+        tw_data->typewriter.setPattern(text_str);
+
+        if (step_length == 0)
+            step_length = 25;
+
+        tw_data->typewriter.setFrameStep(step_length);
+        tw_data->typewriter.setStepSigma(step_sigma);
+        tw_data->typewriter.setStepSeed(random_seed);
+        tw_data->macro_type = macro_type;
+
+        // Apply macro type if specified
+        if (macro_type > 0) {
+            char *buff = new char[text_str.length() + 10];
+            char c = 0;
+            switch (macro_type) {
+            case 1:
+                c = 'c';
+                break; // character
+            case 2:
+                c = 'w';
+                break; // word
+            case 3:
+                c = 'l';
+                break; // line
+            default:
+                break;
+            }
+            if (c != 0) {
+                sprintf(buff, ":%c{%s}", c, text_str.c_str());
+                tw_data->typewriter.setPattern(std::string(buff));
+            }
+            delete[] buff;
+        }
+
+        tw_data->typewriter.parse();
+    }
+
+    std::string rendered_text = tw_data->typewriter.render(position);
+
+    // Add blinking cursor if enabled
+    auto cursor_enabled = mlt_properties_get_int(filter_properties, "typewriter.cursor");
+    if (cursor_enabled) {
+        int cursor_blink_rate = mlt_properties_get_int(filter_properties,
+                                                       "typewriter.cursor_blink_rate");
+        if (cursor_blink_rate < 0)
+            cursor_blink_rate = 25; // Default to 25 frames (1 second at 25fps)
+
+        // Check if we should show cursor (blink on/off)
+        bool show_cursor = (cursor_blink_rate == 0) || (position / cursor_blink_rate) % 2 == 0;
+
+        // Only show cursor if text is still being typed or if we're at the end
+        bool still_typing = !tw_data->typewriter.isEnd();
+
+        if (still_typing || cursor_enabled == 2) { // 2 = always show cursor
+            char *cursor_char = mlt_properties_get(filter_properties, "typewriter.cursor_char");
+            if (!show_cursor) {
+                cursor_char = (char *) " ";
+            } else if (!cursor_char || strlen(cursor_char) == 0) {
+                cursor_char = (char *) "|"; // Default cursor character
+            }
+            rendered_text += cursor_char;
+        }
+    }
+
+    return rendered_text;
+}
+
 static QRectF get_text_path(QPainterPath *qpath,
                             mlt_properties filter_properties,
                             const char *text,
-                            double scale)
+                            double scale,
+                            mlt_position position = 0)
 {
     int outline = mlt_properties_get_int(filter_properties, "outline") * scale;
     char halign = mlt_properties_get(filter_properties, "halign")[0];
@@ -50,8 +166,9 @@ static QRectF get_text_path(QPainterPath *qpath,
 
     qpath->setFillRule(Qt::WindingFill);
 
-    // Get the strings to display
-    QString s = QString::fromUtf8(text);
+    // Get the strings to display (with typewriter effect if enabled)
+    std::string processed_text = get_typewriter_text_for_filter(filter_properties, text, position);
+    QString s = QString::fromUtf8(processed_text.c_str());
     QStringList lines = s.split("\n");
 
     // Configure the font
@@ -75,11 +192,7 @@ static QRectF get_text_path(QPainterPath *qpath,
     height = fm.lineSpacing() * lines.size();
     for (int i = 0; i < lines.size(); ++i) {
         const QString line = lines[i];
-#if (QT_VERSION > QT_VERSION_CHECK(5, 11, 0))
         int line_width = fm.horizontalAdvance(line);
-#else
-        int line_width = fm.width(line);
-#endif
         int bearing = (line.size() > 0) ? fm.leftBearing(line.at(0)) : 0;
         if (bearing < 0)
             line_width -= bearing;
@@ -96,11 +209,7 @@ static QRectF get_text_path(QPainterPath *qpath,
     for (int i = 0; i < lines.size(); ++i) {
         QString line = lines.at(i);
         x = offset;
-#if (QT_VERSION > QT_VERSION_CHECK(5, 11, 0))
         int line_width = fm.horizontalAdvance(line);
-#else
-        int line_width = fm.width(line);
-#endif
         int bearing = (line.size() > 0) ? fm.leftBearing(line.at(0)) : 0;
 
         if (bearing < 0) {
@@ -142,14 +251,19 @@ static QRectF get_text_path(QPainterPath *qpath,
 
 static QColor get_qcolor(mlt_properties filter_properties,
                          const char *name,
+                         mlt_properties frame_properties,
                          int position,
                          int length)
 {
     mlt_color color = mlt_properties_anim_get_color(filter_properties, name, position, length);
+    color = mlt_color_convert_trc(color, mlt_properties_get(frame_properties, "color_trc"));
     return QColor(color.r, color.g, color.b, color.a);
 }
 
-static QPen get_qpen(mlt_properties filter_properties, int position, int length)
+static QPen get_qpen(mlt_properties filter_properties,
+                     mlt_properties frame_properties,
+                     int position,
+                     int length)
 {
     QColor color;
     int outline = mlt_properties_get_int(filter_properties, "outline");
@@ -157,18 +271,21 @@ static QPen get_qpen(mlt_properties filter_properties, int position, int length)
 
     pen.setWidth(outline);
     if (outline) {
-        color = get_qcolor(filter_properties, "olcolour", position, length);
+        color = get_qcolor(filter_properties, "olcolour", frame_properties, position, length);
     } else {
-        color = get_qcolor(filter_properties, "bgcolour", position, length);
+        color = get_qcolor(filter_properties, "bgcolour", frame_properties, position, length);
     }
     pen.setColor(color);
 
     return pen;
 }
 
-static QBrush get_qbrush(mlt_properties filter_properties, int position, int length)
+static QBrush get_qbrush(mlt_properties filter_properties,
+                         mlt_properties frame_properties,
+                         int position,
+                         int length)
 {
-    QColor color = get_qcolor(filter_properties, "fgcolour", position, length);
+    QColor color = get_qcolor(filter_properties, "fgcolour", frame_properties, position, length);
     return QBrush(color);
 }
 
@@ -230,22 +347,27 @@ static void transform_painter(QPainter *painter,
     painter->setTransform(transform);
 }
 
-static void paint_background(
-    QPainter *painter, QRectF path_rect, mlt_properties filter_properties, int position, int length)
+static void paint_background(QPainter *painter,
+                             QRectF path_rect,
+                             mlt_properties filter_properties,
+                             mlt_properties frame_properties,
+                             int position,
+                             int length)
 {
-    QColor bg_color = get_qcolor(filter_properties, "bgcolour", position, length);
+    QColor bg_color = get_qcolor(filter_properties, "bgcolour", frame_properties, position, length);
     painter->fillRect(path_rect, bg_color);
 }
 
 static void paint_text(QPainter *painter,
                        QPainterPath *qpath,
                        mlt_properties filter_properties,
+                       mlt_properties frame_properties,
                        int position,
                        int length)
 {
-    QPen pen = get_qpen(filter_properties, position, length);
+    QPen pen = get_qpen(filter_properties, frame_properties, position, length);
     painter->setPen(pen);
-    QBrush brush = get_qbrush(filter_properties, position, length);
+    QBrush brush = get_qbrush(filter_properties, frame_properties, position, length);
     painter->setBrush(brush);
     painter->drawPath(*qpath);
 }
@@ -324,6 +446,7 @@ static int filter_get_image(mlt_frame frame,
     mlt_filter filter = (mlt_filter) mlt_frame_pop_service(frame);
     char *argument = (char *) mlt_frame_pop_service(frame);
     mlt_properties filter_properties = get_filter_properties(filter, frame);
+    mlt_properties frame_properties = MLT_FRAME_PROPERTIES(frame);
     mlt_profile profile = mlt_service_profile(MLT_FILTER_SERVICE(filter));
     mlt_position position = mlt_filter_get_position(filter, frame);
     mlt_position length = mlt_filter_get_length2(filter, frame);
@@ -346,8 +469,8 @@ static int filter_get_image(mlt_frame frame,
     mlt_rect rect = mlt_properties_anim_get_rect(filter_properties, "geometry", position, length);
 
     // Get the current image
-    *image_format = mlt_image_rgba;
-    mlt_properties_set_int(MLT_FRAME_PROPERTIES(frame), "resize_alpha", 255);
+    *image_format = choose_image_format(*image_format);
+    mlt_properties_set_int(frame_properties, "resize_alpha", 255);
     mlt_service_lock(MLT_FILTER_SERVICE(filter));
     error = mlt_frame_get_image(frame, image, image_format, width, height, writable);
 
@@ -367,7 +490,7 @@ static int filter_get_image(mlt_frame frame,
         }
 
         QImage qimg;
-        convert_mlt_to_qimage_rgba(*image, &qimg, *width, *height);
+        convert_mlt_to_qimage(*image, &qimg, *width, *height, *image_format);
 
         QPainterPath text_path;
 #ifdef Q_OS_WIN
@@ -397,18 +520,28 @@ static int filter_get_image(mlt_frame frame,
                 if (overflowY) {
                     path_rect.setHeight(qMax(path_rect.height(), doc->size().height()));
                 }
-                paint_background(&painter, path_rect, filter_properties, position, length);
+                paint_background(&painter,
+                                 path_rect,
+                                 filter_properties,
+                                 frame_properties,
+                                 position,
+                                 length);
                 doc->drawContents(&painter, drawRect);
             }
         } else {
-            path_rect = get_text_path(&text_path, filter_properties, argument, scale);
+            path_rect = get_text_path(&text_path, filter_properties, argument, scale, position);
             transform_painter(&painter, rect, path_rect, filter_properties, profile);
-            paint_background(&painter, path_rect, filter_properties, position, length);
-            paint_text(&painter, &text_path, filter_properties, position, length);
+            paint_background(&painter,
+                             path_rect,
+                             filter_properties,
+                             frame_properties,
+                             position,
+                             length);
+            paint_text(&painter, &text_path, filter_properties, frame_properties, position, length);
         }
         painter.end();
 
-        convert_qimage_to_mlt_rgba(&qimg, *image, *width, *height);
+        convert_qimage_to_mlt(&qimg, *image, *width, *height);
     }
     mlt_service_unlock(MLT_FILTER_SERVICE(filter));
     free(argument);
@@ -490,6 +623,16 @@ mlt_filter filter_qtext_init(mlt_profile profile, mlt_service_type type, const c
     mlt_properties_set_double(filter_properties, "opacity", 1.0);
     mlt_properties_set_int(filter_properties, "_filter_private", 1);
 
+    // Initialize typewriter properties
+    mlt_properties_set_int(filter_properties, "typewriter", 0);
+    mlt_properties_set_int(filter_properties, "typewriter.step_length", 25);
+    mlt_properties_set_int(filter_properties, "typewriter.step_sigma", 0);
+    mlt_properties_set_int(filter_properties, "typewriter.random_seed", 0);
+    mlt_properties_set_int(filter_properties, "typewriter.macro_type", 1);
+    mlt_properties_set_int(filter_properties, "typewriter.cursor", 1);
+    mlt_properties_set_int(filter_properties, "typewriter.cursor_blink_rate", 25);
+    mlt_properties_set_string(filter_properties, "typewriter.cursor_char", "|");
+
     return filter;
 }
 }
