@@ -1,6 +1,6 @@
 /*
  * filter_drawing.cpp -- draws gps related graphics 
- * Copyright (c) 2015-2022 Meltytech, LLC
+ * Copyright (c) 2015-2025 Meltytech, LLC
  * Original author: Daniel F
  *
  * This library is free software; you can redistribute it and/or
@@ -145,6 +145,9 @@ void draw_legend_grid(mlt_filter filter, mlt_frame frame, QPainter &p, s_base_cr
                                                            get_max_bysrc(filter),
                                                            used_crops.bot,
                                                            used_crops.top);
+        if (pdata->graph_data_source == gspg_location_src) {
+            crt_val = unproject_latitude(crt_val);
+        }
         crt_val = convert_bysrc_to_format(filter, crt_val);
         p.drawText(path_grid_lines.currentPosition().x() + 3,
                    path_grid_lines.currentPosition().y() - 3,
@@ -185,6 +188,8 @@ void draw_now_dot(mlt_filter filter, mlt_frame frame, QPainter &p, s_base_crops
     int thickness = mlt_properties_get_int(properties, "thickness");
     mlt_color dot_color
         = mlt_properties_anim_get_color(properties, "now_dot_color", position, length);
+    dot_color = mlt_color_convert_trc(dot_color,
+                                      mlt_properties_get(MLT_FRAME_PROPERTIES(frame), "color_trc"));
 
     //disc with internal color = white and outer color=now dot color or last used for graph line
     QPen dot_pen = p.pen();
@@ -242,7 +247,8 @@ void draw_main_line_graph(mlt_filter filter, mlt_frame frame, QPainter &p, s_bas
     int thickness = qAbs(mlt_properties_get_int(properties, "thickness"));
     int dots_only = mlt_properties_get_int(properties, "draw_individual_dots");
     char *legend_unit = mlt_properties_get(properties, "legend_unit");
-    QVector<QColor> colors = get_graph_colors(properties, position, length);
+    QVector<QColor> colors
+        = get_graph_colors(properties, MLT_FRAME_PROPERTIES(frame), position, length);
     QPen last_graph_pen;
 
     if (colors.size() < 2)
@@ -294,7 +300,7 @@ void draw_main_line_graph(mlt_filter filter, mlt_frame frame, QPainter &p, s_bas
         int next_i = get_next_valid_gpspoint_index(filter, i);
         if (i == next_i || get_crtval_bysrc(filter, i) == GPS_UNINIT
             || get_crtval_bysrc(filter, next_i) == GPS_UNINIT) {
-            // mlt_log_info(filter, "incomplete pair (i=%d, %d) GPS_UNINIT, skipping drawing", i, next_i);
+            // mlt_log_info(filter, "incomplete pair (i=%d, %d) GPS_UNINIT, skipping drawing\n", i, next_i);
             continue;
         }
 
@@ -453,6 +459,9 @@ void draw_main_line_graph(mlt_filter filter, mlt_frame frame, QPainter &p, s_bas
             p.setFont(font);
             p.setPen(Qt::white);
 
+            if (pdata->graph_data_source == gspg_location_src) {
+                now_val = unproject_latitude(now_val);
+            }
             now_val = convert_bysrc_to_format(filter, now_val);
             QString now_text = QString::number(now_val, 'f', decimals_needed_bysrc(filter, now_val));
             if (pdata->graph_data_source == gspg_location_src) {
@@ -488,7 +497,8 @@ void draw_main_speedometer(mlt_filter filter, mlt_frame frame, QPainter &p, s_ba
     // int color_style = mlt_properties_get_int( properties, "color_style" ) ;
     // int thickness = qAbs( mlt_properties_get_int( properties, "thickness" ) );
     int show_grid = mlt_properties_get_int(properties, "show_grid");
-    QVector<QColor> colors = get_graph_colors(properties, position, length);
+    QVector<QColor> colors
+        = get_graph_colors(properties, MLT_FRAME_PROPERTIES(frame), position, length);
 
     if (colors.size() == 1)
         colors.append(colors[0]);
@@ -598,6 +608,9 @@ void draw_main_speedometer(mlt_filter filter, mlt_frame frame, QPainter &p, s_ba
     if (mlt_properties_get_int(properties, "show_now_dot")) {
         mlt_color dot_color
             = mlt_properties_anim_get_color(properties, "now_dot_color", position, length);
+        dot_color = mlt_color_convert_trc(dot_color,
+                                          mlt_properties_get(MLT_FRAME_PROPERTIES(frame),
+                                                             "color_trc"));
         if (dot_color.a == 0) // if transparent -> use main color
         {
             p.setBrush(colors[0]);
@@ -721,7 +734,7 @@ void prepare_canvas(mlt_filter filter,
                                     rescaled_bg_rect.bottomRight().y()
                                         - rescaled_bg_rect.height() * used_crops.bot / 100.0);
         QRectF crop_rect = QRectF(top_left, bot_right);
-        // mlt_log_info(filter, "crop rect: x,y w,h= %f,%f %f,%f", crop_rect.x(), crop_rect.y(), crop_rect.width(), crop_rect.height());
+        // mlt_log_info(filter, "crop rect: x,y w,h= %f,%f %f,%f\n", crop_rect.x(), crop_rect.y(), crop_rect.width(), crop_rect.height());
 
         //step 4) crop the computed rect from the step 1) scaled image
         p.setOpacity(mlt_properties_get_double(properties, "bg_opacity"));
