@@ -452,11 +452,11 @@ void loadFromXml(producer_ktitle self,
                     QStringList values = gradientData.split(";");
                     if (values.count() < 5) {
                         // invalid gradient, use default
-                        values = {QStringLiteral("#ff0000"),
-                                  QStringLiteral("#2e0046"),
-                                  QStringLiteral("0"),
-                                  QStringLiteral("100"),
-                                  QStringLiteral("90")};
+                        values = QStringList({QStringLiteral("#ff0000"),
+                                              QStringLiteral("#2e0046"),
+                                              QStringLiteral("0"),
+                                              QStringLiteral("100"),
+                                              QStringLiteral("90")});
                     }
                     QLinearGradient gr;
                     gr.setColorAt(values.at(2).toDouble() / 100, values.at(0));
@@ -609,11 +609,11 @@ void loadFromXml(producer_ktitle self,
                     QStringList values = gradientData.split(";");
                     if (values.count() < 5) {
                         // invalid gradient, use default
-                        values = {QStringLiteral("#ff0000"),
-                                  QStringLiteral("#2e0046"),
-                                  QStringLiteral("0"),
-                                  QStringLiteral("100"),
-                                  QStringLiteral("90")};
+                        values = QStringList({QStringLiteral("#ff0000"),
+                                              QStringLiteral("#2e0046"),
+                                              QStringLiteral("0"),
+                                              QStringLiteral("100"),
+                                              QStringLiteral("90")});
                     }
                     QLinearGradient gr;
                     gr.setColorAt(values.at(2).toDouble() / 100, values.at(0));
