@@ -1,6 +1,6 @@
 /*
  * producer_qtext.c -- text generating producer
- * Copyright (C) 2013 Meltytech, LLC
+ * Copyright (C) 2013-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -186,11 +186,7 @@ static void generate_qpath(mlt_properties producer_properties)
     height = fm.lineSpacing() * lines.size();
     for (int i = 0; i < lines.size(); ++i) {
         const QString line = lines[i];
-#if (QT_VERSION > QT_VERSION_CHECK(5, 11, 0))
         int line_width = fm.horizontalAdvance(line);
-#else
-        int line_width = fm.width(line);
-#endif
         int bearing = (line.size() > 0) ? fm.leftBearing(line.at(0)) : 0;
         if (bearing < 0)
             line_width -= bearing;
@@ -207,11 +203,7 @@ static void generate_qpath(mlt_properties producer_properties)
     for (int i = 0; i < lines.size(); ++i) {
         QString line = lines.at(i);
         x = offset;
-#if (QT_VERSION > QT_VERSION_CHECK(5, 11, 0))
         int line_width = fm.horizontalAdvance(line);
-#else
-        int line_width = fm.width(line);
-#endif
         int bearing = (line.size() > 0) ? fm.leftBearing(line.at(0)) : 0;
 
         if (bearing < 0) {
@@ -299,8 +291,11 @@ static void generate_qimage(mlt_properties frame_properties)
     QPainterPath *qPath = static_cast<QPainterPath *>(
         mlt_properties_get_data(frame_properties, "_qpath", NULL));
     mlt_color bg_color = mlt_properties_get_color(frame_properties, "_bgcolour");
+    bg_color = mlt_color_convert_trc(bg_color, mlt_properties_get(frame_properties, "color_trc"));
     mlt_color fg_color = mlt_properties_get_color(frame_properties, "_fgcolour");
+    fg_color = mlt_color_convert_trc(fg_color, mlt_properties_get(frame_properties, "color_trc"));
     mlt_color ol_color = mlt_properties_get_color(frame_properties, "_olcolour");
+    ol_color = mlt_color_convert_trc(ol_color, mlt_properties_get(frame_properties, "color_trc"));
     int outline = mlt_properties_get_int(frame_properties, "_outline");
     qreal sx = 1.0;
     qreal sy = 1.0;
@@ -526,9 +521,15 @@ mlt_producer producer_qtext_init(mlt_profile profile,
                 while (fgets(line, 80, f)) {
                     size += strlen(line) + 1;
                     if (tmp) {
-                        tmp = (char *) realloc(tmp, size);
-                        if (tmp)
+                        // Use a temporary pointer to avoid losing the original buffer on realloc failure
+                        char *newtmp = (char *) realloc(tmp, size);
+                        if (newtmp) {
+                            tmp = newtmp;
                             strcat(tmp, line);
+                        } else {
+                            // Allocation failed: keep existing content and stop appending
+                            break;
+                        }
                     } else {
                         tmp = strdup(line);
                     }
