@@ -31,11 +31,16 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
+#ifdef _MSC_VER
+#include <gettimeofday.h>
+#else
 #include <sys/time.h>
+#endif
 
 #undef MLT_IMAGE_FORMAT // only yuv422 working currently
 
-extern pthread_mutex_t mlt_sdl_mutex;
+MLT_EXPORT extern pthread_mutex_t mlt_sdl_mutex;
 
 /** This classes definition.
 */
