@@ -31,9 +31,14 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/time.h>
 
-extern pthread_mutex_t mlt_sdl_mutex;
+#ifdef _MSC_VER
+#include <gettimeofday.h>
+#else
+#include <sys/time.h>
+#endif
+
+MLT_EXPORT extern pthread_mutex_t mlt_sdl_mutex;
 
 /** This classes definition.
 */
