@@ -15,9 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
- *
- * $Id: xineutils.h 1386 2009-04-10 07:18:41Z ddennedy $
+ * Foundation, Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 #ifndef XINEUTILS_H
@@ -659,7 +657,7 @@ void xine_strdupa(char *dest, char *src);
 #ifdef HAVE_STRPBRK
 #define xine_strpbrk strpbrk
 #else
-static inline const char *_private_strpbrk(const char *s, const char *accept) {
+static inline char *_private_strpbrk(char *s, const char *accept) {
 
   while(*s != '\0') {
     const char *a = accept;
