@@ -274,6 +274,14 @@ static inline void qualify_property(deserialise_context context,
             } else {
                 strcpy(full_resource, resource_orig);
             }
+
+            // Workaround the "&amp;" entity not properly decoded
+            const char *amp_entity = "&#38;";
+            char *amp = strstr(full_resource, amp_entity);
+            while (amp) {
+                memmove(amp + 1, amp + 5, strlen(amp + 5) + 1);
+                amp = strstr(amp + 1, amp_entity);
+            }
             mlt_properties_set_string(properties, name, full_resource);
             free(full_resource);
         }
@@ -2065,6 +2073,8 @@ mlt_producer producer_xml_init(mlt_profile profile,
 
     // Setup libxml2 SAX parsing
     xmlInitParser();
+    // Do not remove the below deprecated function until libxml2 version 2.9.13
+    // is at least 6 years old because in that version XML_PARSE_NOENT does not work.
     xmlSubstituteEntitiesDefault(1);
     // This is used to facilitate entity substitution in the SAX parser
     context->entity_doc = xmlNewDoc(_x("1.0"));
@@ -2079,6 +2089,7 @@ mlt_producer producer_xml_init(mlt_profile profile,
         free(sax);
         return NULL;
     }
+    xmlCtxtUseOptions(xmlcontext, XML_PARSE_NOENT);
 
     // Parse
     sax_orig = xmlcontext->sax;
@@ -2147,7 +2158,7 @@ mlt_producer producer_xml_init(mlt_profile profile,
     xmlcontext->sax = sax;
     xmlcontext->_private = (void *) context;
     xmlParseDocument(xmlcontext);
-    well_formed = xmlcontext->wellFormed;
+    well_formed = xmlcontext->wellFormed && mlt_profile_is_valid(profile);
 
     // Cleanup after parsing
     xmlFreeDoc(context->entity_doc);
